//******************************************************************************
//   MSP430 USCI I2C Transmitter and Receiver (Slave Mode)
//
//  Description: This code configures the MSP430's USCI module as 
//  I2C slave capable of transmitting and receiving bytes. 
//
//  ***THIS IS THE SLAVE CODE***
//
//                    Slave                   
//                 MSP430F2619             
//             -----------------          
//         /|\|              XIN|-   
//          | |                 |     
//          --|RST          XOUT|-    
//            |                 |        
//            |                 |        
//            |                 |       
//            |         SDA/P3.1|------->
//            |         SCL/P3.2|------->
//
// Note: External pull-ups are needed for SDA & SCL
//
// Uli Kretzschmar
// Texas Instruments Deutschland GmbH
// November 2007
// Built with IAR Embedded Workbench Version: 3.42A
//******************************************************************************
#include "msp430x22x4.h"
#include "TI_USCI_I2C_slave.h"

extern unsigned char mUartCount;

void (*TI_receive_callback)(unsigned char receive); 
void (*TI_transmit_callback)(unsigned char volatile *send_next); 
void (*TI_start_callback)(void); 

void (*TI_UART_transmit_callback)(unsigned char volatile *send_next); 

//------------------------------------------------------------------------------
// void TI_USCI_I2C_slaveinit(void (*SCallback)(),
//                            void (*TCallback)(unsigned char volatile *value),
//                            void (*RCallback)(unsigned char value), 
//                            unsigned char slave_address)
//
// This function initializes the USCI module for I2C Slave operation. 
//
// IN:   void (*SCallback)() => function is called when a START condition was detected
//       void (*TCallback)(unsigned char volatile *value) => function is called for every byte requested by master
//       void (*RCallback)(unsigned char value) => function is called for every byte that is received 
//       unsigned char slave_address  =>  Slave Address
//------------------------------------------------------------------------------
#if 0
void TI_USCI_I2C_slaveinit(void (*SCallback)(),
                           void (*TCallback)(unsigned char volatile *value),
                           void (*RCallback)(unsigned char value), 
                           unsigned char slave_address){
  P3SEL |= SDA_PIN + SCL_PIN;               // Assign I2C pins to USCI_B0
  UCB0CTL1 |= UCSWRST;                      // Enable SW reset
  UCB0CTL0 = UCMODE_3 + UCSYNC;             // I2C Slave, synchronous mode
  UCB0I2COA = slave_address;                // set own (slave) address
  UCB0CTL1 &= ~UCSWRST;                     // Clear SW reset, resume operation
  IE2 |= UCB0TXIE + UCB0RXIE;               // Enable TX interrupt
  UCB0I2CIE |= UCSTTIE;                     // Enable STT interrupt
  TI_start_callback = SCallback;
  TI_receive_callback = RCallback;
  TI_transmit_callback = TCallback;
}
#endif

//------------------------------------------------------------------------------
// void TI_USCI_I2C_slaveinit(void (*SCallback)(),
//                            void (*TCallback)(unsigned char volatile *value),
//                            void (*RCallback)(unsigned char value), 
//                            unsigned char slave_address)
//
// This function initializes the USCI module for I2C Slave operation. 
//
// IN:   void (*SCallback)() => function is called when a START condition was detected
//       void (*TCallback)(unsigned char volatile *value) => function is called for every byte requested by master
//       void (*RCallback)(unsigned char value) => function is called for every byte that is received 
//       unsigned char slave_address  =>  Slave Address
//------------------------------------------------------------------------------
void TI_UART_init(void (*UARTCallback)(unsigned char volatile *value))
{
	//WDTCTL = WDTPW + WDTHOLD;                 // Stop WDT

#ifdef Enable_OSC_8MHz
	BCSCTL1 = CALBC1_8MHZ;                     //Set DCO
	DCOCTL = CALDCO_8MHZ;
	UCA0BR0 = 69;                              // 1MHz 115200
	UCA0BR1 = 0;                              // 1MHz 115200
	UCA0MCTL = UCBRS_4;               // Modulation UCBRSx = 5		
#else
	BCSCTL1 = CALBC1_1MHZ;                     //Set DCO
	DCOCTL = CALDCO_1MHZ;
	UCA0BR0 = 8;                              // 1MHz 115200
	UCA0BR1 = 0;                              // 1MHz 115200
	UCA0MCTL = UCBRS2 + UCBRS0;               // Modulation UCBRSx = 5
#endif	

	P3SEL |= 0x30;	// P3.4,5 = USCI_A0 TXD/RXD
	UCA0CTL1 |= UCSSEL_2;                     // SMCLK
	UCA0CTL1 &= ~UCSWRST;                     // **Initialize USCI state machine**

	TI_UART_transmit_callback=UARTCallback;
}

// USCI_B0 Data ISR
#pragma vector = USCIAB0TX_VECTOR
__interrupt void USCIAB0TX_ISR(void)
{

#if 1
if((IFG2&UCA0TXIFG)&&(IE2&UCA0TXIE)) // Check for UART TX
//if(mUartCount)
{
	TI_UART_transmit_callback(&UCA0TXBUF);
	mUartCount=0;	
	IE2 &= ~UCA0TXIE; // Disable USCI_A0 TX interrupt
}
#endif

//else if (IFG2 & UCB0TXIFG)
//TI_transmit_callback(&UCB0TXBUF);
//else if (IFG2 & UCB0RXIFG)
//TI_receive_callback(UCB0RXBUF);
}

// USCI_B0 State ISR
#pragma vector = USCIAB0RX_VECTOR
__interrupt void USCIAB0RX_ISR(void)
{
  UCB0STAT &= ~UCSTTIFG;                    // Clear start condition int flag
  TI_start_callback();
}
