/*****************************************************************************
**
**             TEXAS INSTRUMENTS PROPRIETARY INFORMATION
**
**  (c) Copyright, Texas Instruments Incorporated, 2008
**      All Rights Reserved.
**
**  Property of Texas Instruments Incorporated. Restricted Rights -
**  Use, duplication, or disclosure is subject to restrictions set
**  forth in TI's program license agreement and associated documentation.
******************************************************************************/
/*************************************************************
* THIS PROGRAM IS PROVIDED "AS IS." TI MAKES NO WARRANTIES OR
* REPRESENTATIONS, EITHER EXPRESS, IMPLIED OR STATUTORY,
* INCLUDING ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR PURPOSE, LACK OF VIRUSES, ACCURACY OR
* COMPLETENESS OF RESPONSES, RESULTS AND LACK OF NEGLIGENCE.
* TI DISCLAIMS ANY WARRANTY OF TITLE, QUIET ENJOYMENT, QUIET
* POSSESSION, AND NON-INFRINGEMENT OF ANY THIRD PARTY
* INTELLECTUAL PROPERTY RIGHTS WITH REGARD TO THE PROGRAM OR
* YOUR USE OF THE PROGRAM.
*
* IN NO EVENT SHALL TI BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
* CONSEQUENTIAL OR INDIRECT DAMAGES, HOWEVER CAUSED, ON ANY
* THEORY OF LIABILITY AND WHETHER OR NOT TI HAS BEEN ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGES, ARISING IN ANY WAY OUT
* OF THIS AGREEMENT, THE PROGRAM, OR YOUR USE OF THE PROGRAM.
* EXCLUDED DAMAGES INCLUDE, BUT ARE NOT LIMITED TO, COST OF
* REMOVAL OR REINSTALLATION, COMPUTER TIME, LABOR COSTS, LOSS
* OF GOODWILL, LOSS OF PROFITS, LOSS OF SAVINGS, OR LOSS OF
* USE OR INTERRUPTION OF BUSINESS.  IN NO EVENT WILL TI'S
* AGGREGATE LIABILITY UNDER THIS AGREEMENT OR ARISING OUT OF
* YOUR USE OF THE PROGRAM EXCEED FIVE HUNDRED DOLLARS
* (U.S.$500).
*
* Unless otherwise stated, the Program is written and copyrighted
* by Texas Instruments is distributed as "freeware."  You may,
* only under TI's copyright in the Program, use and modify the
* Program without any charge or restriction.  You may
* distribute to third parties, provided that you transfer a
* copy of this license to the third party and the third party
* agrees to these terms by its first use of the Program.  In
* jurisdictions in which use is not deemed acceptance of these
* terms, no license is granted and no use is permitted.  You
* must reproduce the copyright notice and any other legend of
* ownership on each copy or partial copy of the Program.
*
* You acknowledge and agree that the Program contains
* copyrighted material, trade secrets and other TI proprietary
* information and is protected by copyright laws,
* international copyright treaties, and trade secret laws, as
* well as other intellectual property laws.  You agree that in
* no event will you alter, remove or destroy any copyright
* notice included in the Program.  TI reserves all rights not
* specifically granted under this license.  Except as
* specifically provided herein, nothing in this agreement
* shall be construed as conferring upon you, by implication,
* estoppel, or otherwise, any license or other right under any
* TI patents, copyrights or trade secrets.
*************************************************************/
#include "common.h"
#include "msp430x22x4.h"	//org ==> //#include "msp430f2132.h"
#include "dpp343x.h"
#include "ddp343xEVM.h"
#include "ddp343xEVM_pins.h"
#include "i2c_master.h"
#include "TimerProcess.h"

// external variables
//extern uint08 tpg_select;
//extern uint08 splash_image_select;
extern void Hold(uint32 x);

uint08 Pico_HActive[2];
uint08 Pico_VActive[2];

extern uint16 DMDx, DMDy;
////////////////////////////////////////////////////////////

uint08 dpp3430_config_tpg(uint08 pattern_select)
/**
 * Configure datapath for test pattern generator operation
 *
 * @param   pattern_select - I - color table to load
 *
 * @return  0 - no errors
 *          1 - invalid pattern specified
 *
 */
{
  	uint08 Param[8];
  	uint08 n = 1;
  
    // Test patterns have up to 9 choices
  	if ( pattern_select > TPG_COLOR_BARS )
    	return 1;
  
  	DPP_set_curtaincolor(CURTAIN_BLACK);

  	//Disbale TVP LED if moving to Splash/TPG source.
  	//P3OUT &= ~LED_TVP_ENA;
  
	// Freeze the image
    //Param[0] = 1;
    //write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_IMAGE_FREEZE, Param, 1);

 	// Write Image Crop (No Crop)
    Param[0] = 0;
    Param[1] = 0;
    Param[2] = 0;
    Param[3] = 0;

	Param[4] = (uint08) (DMDx & 0x00ff);
	Param[5] = (uint08) (DMDx >> 8);  // Pixel per line
	Param[6] = (uint08) (DMDy & 0x00ff);
	Param[7] = (uint08) (DMDy >> 8);  // Lines per frame

    write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_IMAGE_CROP, Param, 8);
   
    // DMD size assumed to be 854x480 or 0x356 by 0x1E0
//    Param[0] = 0x56;
//    Param[1] = 0x03;  // Pixel per line
//    Param[2] = 0xE0;
//    Param[3] = 0x01;  // Lines per frame
	
	// DMD size is set by what DMD ID is get
	Param[0] = (uint08) (DMDx & 0x00ff);
	Param[1] = (uint08) (DMDx >> 8);  // Pixel per line
	Param[2] = (uint08) (DMDy & 0x00ff);
	Param[3] = (uint08) (DMDy >> 8);  // Lines per frame
    write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_DISPLAY_SIZE, Param, 4);
    
  	// Write Input Source Select
	Param[0] = 1;   // Internal test pattern generator
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_INPUT_SOURCE_SELECT, Param, 1);

	// Write Display Image Orientation    (NO Flip)
	//Param[0] = 0;
	//write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_DISPLAY_IMAGE_ORIENTATION, Param, 1);
    
    // Write test pattern select as common parapmeter; also enable it
    Param[0] = pattern_select | 0x80;
    
    switch (pattern_select)
    {
    	case TPG_SOLID_FIELD:
    		Param[1] = 0x10;   // Red foreground/ Black background    	
    	    n = 2;
    		break;
    		
    	case TPG_HORIZONTAL_RAMP:
    	case TPG_VERTICAL_RAMP:
    		Param[1] = 0x70;  // White foreground/ Black background    	    	
    		Param[2] = 0;     // Start Value
    		Param[3] = 255;   // Stop Value
    		n = 4;    	
			break;
			
    	case TPG_HORIZONTAL_LINES:
    	    Param[1] = 0x20;    // Green foreground/ Black background    
    	    Param[2] = 4;       // Foreground line width
    		Param[3] = 8;       // Background line width
    		n = 4;
    		break;
    		
    	case TPG_DIAG_LINES:
    		Param[1] = 0x07;     // Black foreground/ White background        	
    	    Param[2] = 15;       // Horizontal spacing
    		Param[3] = 15;       // Vertical spacing   	
    		n = 4;
    		break;	
    		    	
    	case TPG_VERTICAL_LINES:
    	    Param[1] = 0x70;    // White foreground/ Black background    
    	    Param[2] = 8;       // Foreground line width
    		Param[3] = 4;       // Background line width
    		n = 4;    	
    	    break;
    	        		
    	case TPG_GRID_LINES:
    	    Param[1] = 0x70;    // White foreground/ Black background    
    	    Param[2] =2;        // Horizontal Foreground line width
    		Param[3] =8;        // Horizontal Background line width
    		Param[4] =2;        // Vertical Foreground line width
    		Param[5] =8;        // Vertical Background line width
    		n = 6;
    		break;
    		
    	case TPG_CHECKER_BOARD:
    		Param[1] = 0x70;    // White foreground/ Black background        	
 			Param[2] =16;        // # of Horizontal Checkers (LSB)
    		Param[3] =0;        // # of Horizontal Checkers  (MSB)
    		Param[4] =12;        // # of Vertical Checkers  (LSB)
    		Param[5] =0;        // # of Vertical Checkers   (MSB)
    		n = 6;	
    		break;
    		
    	case TPG_COLOR_BARS:
    	   n = 1;
    	   break;
    	default:
    		break;
    }
        
    write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_TEST_PATTERN_SELECT, Param, n);
      
	// Write image freeze Disable	 
	//Param[0] = 0;
    //write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_IMAGE_FREEZE, Param, 1);
      
  	DPP_enable_curtain(FALSE);
  	
 	 // no errors
  	return 0;
}

////////////////////////////////////////////////////////////

uint08 dpp3430_config_splash(uint08 image_number)
/**
 * Configure datapath for splash image operation
 *
 * @param   image_number - I - splash image to load from flash
 *
 * @return  0 - no errors
 *          1 - invalid image_number specified
 *
 */
{
	uint08 Param[8];	//, i;
	uint16 x, y;
	
  	//Disbale TVP LED if moving to Splash source.
  	//P3OUT &= ~LED_TVP_ENA;
  	
	// Write Display Image Curtain
  	DPP_set_curtaincolor (CURTAIN_BLACK);
  	  	
    // Freeze the image
    //Param[0] = 1;
    //write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_IMAGE_FREEZE, &Param[0], 1);
	
    // Write Splash Screen Select 0D : Number 0, 1, 2, etc
	Param[0] = image_number;
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_SPLASH_SCREEN_SELECT, Param, 1);

	x = 0;
	y = 0;
	GetSplashScreenDimention (image_number, &x, &y);
	
	// x = Width, y = Height
 	// Write Image Crop (No Crop) 640x480   0x80, 0x02, 0xE0, 0x01
    Param[0] = 0;
    Param[1] = 0;
    Param[2] = 0;
    Param[3] = 0;
    Param[4] = (uint08) (x & 0x00ff); // LSB  Width
    Param[5] = (uint08) (x >> 8);     // MSB  Width
    Param[6] = (uint08) (y & 0x00ff); // LSB  Height
    Param[7] = (uint08) (y >> 8);     // MSB  Height
    write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_IMAGE_CROP, Param, 8);

 	// Write External Input Image Size 864x480 for RGB Parallel Bus
	Param[0] = (uint08) (x & 0x00ff); // LSB  Width
	Param[1] = (uint08) (x >> 8);     // MSB  Width
	Param[2] = (uint08) (y & 0x00ff); // LSB  Height
	Param[3] = (uint08) (y >> 8);     // MSB  Height
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_EXTERNAL_INPUT_IMAGE_SIZE, Param, 4);
   
    // DMD size assumed to be 854x480 or 0x356 by 0x1E0
//    Param[0] = 0x56;
//    Param[1] = 0x03;  // Pixel per line
//    Param[2] = 0xE0;
//    Param[3] = 0x01;  // Lines per frame

	// DMD size is set by what DMD ID is get
	Param[0] = (uint08) (DMDx & 0x00ff);
	Param[1] = (uint08) (DMDx >> 8);  // Pixel per line
	Param[2] = (uint08) (DMDy & 0x00ff);
	Param[3] = (uint08) (DMDy >> 8);  // Lines per frame
    write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_DISPLAY_SIZE, Param, 4);
    
	// Write Display Image Orientation    (NO Flip)
	//Param[0] = 0;
	//write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_DISPLAY_IMAGE_ORIENTATION, Param, 1);
	    
	// Write internal VSYNC rate (60Hz)
	//Param[0] = 0x40;
	//Param[1] = 0x42;
	//Param[2] = 0x0F;
	//Param[3] = 0x00;
	//write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_INTERNAL_VSYNC_RATE, Param, 4);
	
 	// Write Input Source Select
	Param[0] = 2;   // Splash screen
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_INPUT_SOURCE_SELECT, Param, 1);
	
	// Write Splash screen execute
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_SPLASH_SCREEN_EXECUTE, NULL, 0);
// 2013-1204 disable ->	for (i=0; i<2; i++)
// 2013-1204 disable ->		Hold (500000);

	delay1ms(500);
    
	// Write image freeze Disable	 
	//Param[0] = 0;
    //write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_IMAGE_FREEZE, Param, 1);

    // Disable curtain
    DPP_enable_curtain (FALSE);
        
	return 0; 
}

/////////////////////////////////////////////////////////
// 24-bit Parallel RGB bus selection

void dpp3430_config_rgb(void)
/**
 * Configure datapath for parallel RGB operation 
 * using DVI board
 *
 */
{
  	uint08 Param[8];
        
  	DPP_set_curtaincolor(CURTAIN_BLACK);
  
 	// Freeze the image
    Param[0] = 1;
    write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_IMAGE_FREEZE, &Param[0], 1);

#ifdef ENABLE_TVP5151  
 	// Write Image Crop (No Crop)
    Param[0] = 0;
    Param[1] = 0;
    Param[2] = 0;
    Param[3] = 0;
//    Param[4] = 0x60;
//    Param[5] = 0x03;
//    Param[6] = 0xE0;
//    Param[7] = 0x01;
    Param[4] = 0xFF;
    Param[5] = 0xFF;
    Param[6] = 0xFF;
    Param[7] = 0xFF;
    write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_IMAGE_CROP, Param, 8);
   
    // DMD size assumed to be 854x480 or 0x356 by 0x1E0  
//    Param[0] = 0x56;
//    Param[1] = 0x03;  // Pixel per line
//    Param[2] = 0xE0;
//    Param[3] = 0x01;  // Lines per frame

	// DMD size is set by what DMD ID is get
	Param[0] = (uint08) (DMDx & 0x00ff);
	Param[1] = (uint08) (DMDx >> 8);  // Pixel per line
	Param[2] = (uint08) (DMDy & 0x00ff);
	Param[3] = (uint08) (DMDy >> 8);  // Lines per frame
    write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_DISPLAY_SIZE, Param, 4);
    
	// Write Display Image Orientation    (NO Flip)
	//Param[0] = 0;
	//write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_DISPLAY_IMAGE_ORIENTATION, Param, 1);  
			
 	// Write External Input Image Size 864x480 for RGB Parallel Bus

	Param[0] = Pico_HActive[0];
	Param[1] = Pico_HActive[1];
	Param[2] = Pico_VActive[0];
	Param[3] = Pico_VActive[1];
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_EXTERNAL_INPUT_IMAGE_SIZE, Param, 4);
#else
	// Write Image Crop (No Crop)
	Param[0] = 0;
	Param[1] = 0;
	Param[2] = 0;
	Param[3] = 0;

	Param[4] = Pico_HActive[0];
	Param[5] = Pico_HActive[1];
	Param[6] = Pico_VActive[0];
	Param[7] = Pico_VActive[1];

	write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_IMAGE_CROP, Param, 8);

	// DMD size is set by what DMD ID is get
	Param[0] = (uint08) (DMDx & 0x00ff);
	Param[1] = (uint08) (DMDx >> 8);  // Pixel per line
	Param[2] = (uint08) (DMDy & 0x00ff);
	Param[3] = (uint08) (DMDy >> 8);  // Lines per frame
	write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_DISPLAY_SIZE, Param, 4);

	Param[0] = Pico_HActive[0];
	Param[1] = Pico_HActive[1];
	Param[2] = Pico_VActive[0];
	Param[3] = Pico_VActive[1];
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_EXTERNAL_INPUT_IMAGE_SIZE, Param, 4);	
#endif
	
	// Write external video source select RGB888 0x43
	Param[0] = 0x43;   // External Video Source Select
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_SOURCE_FORMAT_SELECT, Param, 1);
				
 	// Write Input Source Select
	Param[0] = 0;   // External Video Port
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_INPUT_SOURCE_SELECT, Param, 1);	
	
  	// delay 100ms for source detection
  	Hold (100000);
  	
	// Write image freeze Disable	 
	Param[0] = 0;
    write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_IMAGE_FREEZE, Param, 1);
      	
  	DPP_enable_curtain(FALSE);
}

////////////////////////////////////////////////////////////////////////////
void dpp3430_Init_Decoder (void)
{
#ifdef ENABLE_TVP5151  
//
//	  // powerup TVP5151
//	  P1OUT |= TVP5150_PDz;
//
//	  // wait for 100 ms to de-assert TVP reset
//	  Hold(100000);
//
//	  // remove reset of TVP5151
//	  P1OUT |= TVP5150_RSTz;
//
//	  Hold(200);
//
//	  // write TVP registers
//	  write_i2c_1byte(TVP5150_DEV_ADDR, 0x02, 0x00);
//
//	  write_i2c_1byte(TVP5150_DEV_ADDR, 0x00, 0x00);
//	  write_i2c_1byte(TVP5150_DEV_ADDR, 0x03, 0x6d);
//	  write_i2c_1byte(TVP5150_DEV_ADDR, 0x05, 0x02);
//	  write_i2c_1byte(TVP5150_DEV_ADDR, 0x0d, 0x47);
//	  write_i2c_1byte(TVP5150_DEV_ADDR, 0x11, 0x00);
//	  write_i2c_1byte(TVP5150_DEV_ADDR, 0x12, 0x04);
//	  write_i2c_1byte(TVP5150_DEV_ADDR, 0x18, 0x00);
//	  write_i2c_1byte(TVP5150_DEV_ADDR, 0x19, 0x00);
//	  write_i2c_1byte(TVP5150_DEV_ADDR, 0x09, 0x80);
#endif	  
}

////////////////////////////////////////////////////////////////////////////
// Bring up video decoder

uint08 dpp3430_config_tvp(void)
/**
 * Configure datapath for BT-656 operation with TVP5150 video decoder
 *
 * @return  0 - no errors
 *          1 - invalid or no source found
 *
 */
{
#ifdef ENABLE_TVP5151  
//  uint08 Param[8];
//  uint08 locked, status1, status2, status5,i2c_status;
//  uint08 standard, resolution;
//    
//  resolution = NTSC_LANDSCAPE;
//  DPP_set_curtaincolor(CURTAIN_BLACK);
//  
//  dpp3430_Init_Decoder ();
//   // delay for source detection
//   // Below delay is just arbitrary. Delay can be further 
//   // optimized by polling the status bits and time out in case there is no source
//   Hold (500000);
//   Hold (500000);
//   Hold (500000);
//   Hold (500000);
//   
//   // find out if a signal is present and
//   // what type of signal it is
//   locked = 0;
//   i2c_status = read_i2c_1byte(TVP5150_DEV_ADDR, 0x03, &locked);
//   if(i2c_status == 0) 
//   {
//	    locked = 0;
//   	    i2c_status = read_i2c_1byte(TVP5150_DEV_ADDR, 0xc0, &locked);
//   }
//
//   if(i2c_status == 0) 
//   		i2c_status = read_i2c_1byte(TVP5150_DEV_ADDR, 0x88, &status1);
//  
//   if(i2c_status == 0) 
//   		i2c_status = read_i2c_1byte(TVP5150_DEV_ADDR, 0x89, &status2);
//  
//   if(i2c_status == 0) 
//   		i2c_status = read_i2c_1byte(TVP5150_DEV_ADDR, 0x8c, &status5);
//
//   if(i2c_status != 0)
//     return 1;
//  
//   standard = (status5 >> 1) & 7;
//
//   // clear the interrupts
//   write_i2c_1byte(TVP5150_DEV_ADDR, 0xc0, locked);
//
//   // if the source is locked, find out what field rate the source is
//   if ( (status1 & 6) == 6 ) 
//   {
//     if ( status1 & BIT5 ) 
//     { // 50 Hz field rate
//       // verify PAL was identified
//       switch (standard) 
//       {
//         case 1 || 2 || 3:
//           resolution = PAL_LANDSCAPE;
//           break;
//         default:
//           // not a valid source (could it be SECAM?)
//           DPP_set_curtaincolor(CURTAIN_BLUE);
//           return 1;
//       }
//     } 
//     else 
//     { 
//     	// 60 Hz field rate
//        // verify it is normal NTSC (not NTSC 4.43)
//        if ( standard == 0 )
//          resolution = NTSC_LANDSCAPE;
//        else 
//        {
//       	    // Error
//            DPP_set_curtaincolor(CURTAIN_CYAN);
//            return 1;  // not standard NTSC
//        }
//      }
//   } 
//   else 
//   { 
//   	   // not locked
//       DPP_set_curtaincolor(CURTAIN_YELLOW);   	   
//       return 1;  // not locked
//   }
//
//    // Talk to DPP343x
// 	// Freeze the image
//    Param[0] = 1;
//    write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_IMAGE_FREEZE, &Param[0], 1);
//    
//	// Write external video source select BT656 0xA0 (YCbCr4:2:2)
//	Param[0] = 0xA0;   // External Video Source Select
//	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_SOURCE_FORMAT_SELECT, Param, 1);
//
//    // Write input image size
//    if (resolution == NTSC_LANDSCAPE)
//    {
// 	    // Write External Input Image 720x240
//	    Param[0] = 0xD0;
//	    Param[1] = 0x02;
//	    Param[2] = 0xF0;
//	    Param[3] = 0x00;
//    }
//    else
//    {
// 	    // Write External Input Image PAL 720x288 (0x2D0 x 0x0120)
//	    Param[0] = 0xD0;
//	    Param[1] = 0x02;
//	    Param[2] = 0x20;
//	    Param[3] = 0x01;    	
//    }
//    
//	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_EXTERNAL_INPUT_IMAGE_SIZE, Param, 4);
//		    
//	// Write Image Crop 720x240
//    Param[0] = 0;
//    Param[1] = 0;
//    Param[2] = 0;
//    Param[3] = 0;
//    
//    if (resolution == NTSC_LANDSCAPE)
//    {
//    	Param[4] = 0xD0;
//    	Param[5] = 0x02;
//    	Param[6] = 0xF0;
//    	Param[7] = 0x00;
//    }
//    else
//    {
// 	    // Write External Input Image PAL 720x288
//	    Param[4] = 0xD0;
//	    Param[5] = 0x02;
//	    Param[6] = 0x20;
//	    Param[7] = 0x01;     	
//    }
//    
//    write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_IMAGE_CROP, Param, 8);
//   
//    // DMD size assumed to be 854x480 or 0x356 by 0x1E0
//    Param[0] = 0x56;
//    Param[1] = 0x03;  // Pixel per line
//    Param[2] = 0xE0;
//    Param[3] = 0x01;  // Lines per frame
//    write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_DISPLAY_SIZE, Param, 4);
//    
//	// Write Display Image Orientation    (NO Flip)
//	//Param[0] = 0;
//	//write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_DISPLAY_IMAGE_ORIENTATION, Param, 1);  
//		
//	// Write ExternalVideoChromaProcessing: 
//	// YCbCr = 0, Luma Offset = 0, 
//	// Chroma Swap = CbCr (0), 
//	// Chroma Interpolation = Chroma Interpolation(0), 
//	// CSC Coefficient Set = 0
//	Param[0] = 0;
//    Param[1] = 0;
//	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_EXTERNAL_CHROMA_PROCESS, Param, 2);
//	
// 	// Write Input Source Select
//	Param[0] = 0;   // External Video Port
//	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_INPUT_SOURCE_SELECT, Param, 1);
//		
//    Hold (500000);
//    		
//	// Write image freeze Disable	 
//	Param[0] = 0;
//    write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_IMAGE_FREEZE, Param, 1);
//        		
//    // no errors
//    DPP_enable_curtain(FALSE);
#endif	
    return 0;
}

///////////////////////////////////////////////
/**********   Curtain Functions *************/
void DPP_enable_curtain(uint08 enable)
/*
 * Enable image curtain. Curtain color can be set by calling function DPP_set_curtaincolor(color)  
 *
 * @param   enable - I - TRUE  = Enable image curtain
 *                       FALSE = Disable image curtain
 * 
 * @return  none
 * 
 */
{
	uint08 read;
	
	read = 0;
	read_dpp3430_i2c(DPP3430_DEV_ADDR, READ_CURTAIN_CONTROL, NULL, 0, &read, 1);
	if(enable)
	{
		read |= 0x01;
	}
	else
	{
		read &= ~0x01;
	}
		
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_CURTAIN_CONTROL, &read, 1);					
}

////////////////////////////////////////////////////////

uint08 DPP_is_curtain_enable(void)
/*
 * This function returns the status of image curtain.
 *
 * @return  TRUE   = Enabled
 *          FALSE  = Disabled
 */
{
	uint08 read;
	read_dpp3430_i2c(DPP3430_DEV_ADDR, READ_CURTAIN_CONTROL, NULL, 0, &read, 1);
	if(read & 0x1)
		return TRUE;
	else
		return FALSE;			
}

///////////////////////////////////////////////////////////

void DPP_set_curtaincolor(uint08 color)
/*
 * Enable image curtain. Curtain color can be set by calling function DPP_set_curtaincolor(color)  
 *
 * @param   color  - I - 	CURTAIN_BLACK        = 0     
 *							CURTAIN_RED          = 1     
 *							CURTAIN_GREEN             
 *							CURTAIN_BLUE              
 *							CURTAIN_YELLOW            
 *							CURTAIN_MAGENTA           
 *							CURTAIN_CYAN              
 *							CURTAIN_WHITE        = 7    
 * 
 * @return  none
 * 
 * Note: This function does not enable/disable image curtain. It only modifies the curtain color. To enable/disbale 
 * image curtain call function DPP_enable_curtain(enable)
 */ 
{
	uint08 read = 0;
	// No input param for read curtain
	//read_dpp3430_i2c(DPP3430_DEV_ADDR, READ_CURTAIN_CONTROL, NULL, 0, &read, 1);
	// Always enable the curtain B0.
	read |= 0x1;
	// Add the color
	read |= (color << 1);
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_CURTAIN_CONTROL, &read, 1);				
} 

/////////////////////////////////////////////////////////////////

uint32 dpp3430_read_short_status ()
{
	uint08 dpp3430_status = 0xff;
	uint08 i;
				
   	for (i=0; i<50; i++)
  	{
      read_dpp3430_i2c(DPP3430_DEV_ADDR, READ_SHORT_STATUS, NULL, 0, &dpp3430_status, 1);
      if (dpp3430_status == 0)
      {
      	break;
      }
      // Wait for 100 ms
      Hold (100000);
	}
		
	return dpp3430_status;	
}	

////////////////////////////////////////////

uint08 GetSplashScreenDimention (uint08 index, uint16 *x, uint16 *y)
{
	SPLASH_HEADER SplashHeader;
	uint08 Param;
	
	Param = index;
    read_dpp3430_i2c(DPP3430_DEV_ADDR, READ_SPLASH_SCREEN_HEADER, &Param, 1, (uint08 *)&SplashHeader, sizeof (SplashHeader));
    *x = SplashHeader.Image_width;
    *y = SplashHeader.Image_height;
    
	return TRUE;
}

////////////////////////////////////////////////

uint08 Pad2000Used ()
{
	uint08 pad2000ID = TRUE;
	uint08 param[5];

	param[0] = 0;
	param[1] = 0;
	param[2] = 0;
	param[3] = 1;
	param[4] = 1;

	write_dpp3430_i2c(DPP3430_DEV_ADDR, PAD_WRITE_REQUEST, param, 5);

	read_dpp3430_i2c(DPP3430_DEV_ADDR, READ_PAD_ID, NULL, 0, (uint08 *)&pad2000ID, sizeof (uint08));

	switch (pad2000ID)
	{
		case PAD_2000_ID_OLD:
		case PAD_2000_ID:
			pad2000ID = TRUE;
			break;
		case PAD_2005_ID:
			pad2000ID = FALSE;
			break;
		default:
			pad2000ID = TRUE;
			break;
	}

	return pad2000ID;
}

////////////////////////////////////////////////
#if 0 // Not used
static SIZE_TABLE SizeTable[6];

uint08 dpp3430_read_OEM_ScratchPad ()
{
	uint08 TypeSel[4];
	uint08 ByteLen[2];
	uint16 Len;
	OSD_HEADER osdHd;

	read_dpp3430_i2c(DPP3430_DEV_ADDR, READ_SYSTEM_SW_VERSION, NULL, 0, (uint08 *)TypeSel, 4);
	read_dpp3430_i2c(DPP3430_DEV_ADDR, READ_ASIC_DEVICE_ID, NULL, 0, (uint08 *)TypeSel, 1);

	// Sequence of executing Flash command
	// Flash Data Type Select (DEh): Partial OEM Scratch Pad Set 3: 0xB7
	// Flash Data Length (DFh) Read Max n bytes
	// Read Flash Start (E3h)
	// Flash Data Length (DFh) Read Max n bytes
	// Read Flash Continue (E4)

	TypeSel[0] = 0xB7;  // Partial OEM Scratchpad Data Set 3
	TypeSel[1] = 0; // First relative sector 0
	TypeSel[2] = 0; // LSB   // Offset 0
	TypeSel[3] = 0; // MSB
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_FLASH_DATA_TYPE_SELECT, &TypeSel[0], 4);

	Len = sizeof (OSD_HEADER) - sizeof (SIZE_TABLE);

	ByteLen[0] = (uint08) (Len & 0x00ff);         // LSB
	ByteLen[1] = (uint08) ((Len & 0xff00) >> 8);  // MSB
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_FLASH_DATA_LENGTH, (uint08 *) &ByteLen, 2);

	// Read first batch of bytes, including signature and # of OSD
	read_dpp3430_i2c(DPP3430_DEV_ADDR, READ_FLASH_START, NULL, 0, (uint08 *)&osdHd, Len);

	if ((osdHd.id[0] == 'O') && (osdHd.id[1] == 'S') && (osdHd.id[2] == 'D') && (osdHd.id[3] == 'H'))
	{
		// read Size, Start bytes
		Len = (uint16) (osdHd.count * sizeof (SIZE_TABLE));

		ByteLen[0] = (uint08) (Len & 0x00ff);         // LSB
		ByteLen[1] = (uint08) ((Len & 0xff00) >> 8);  // MSB
		write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_FLASH_DATA_LENGTH, (uint08 *) &ByteLen, 2);

		read_dpp3430_i2c(DPP3430_DEV_ADDR, READ_FLASH_CONTINUE, NULL, 0, (uint08 *)&SizeTable[0], Len);

		// Palette start: Start Addr + 10; read 64 bytes as palette
		// OSD Data size: Start Addr + 74: read 2 bytes as Data Size.
		// Actual OSD Data: Offset (Start addr + 76) with OSD Data Size in bytes.
		//osdHd.count

		// Read 128 = 0x0080 bytes next
		//ByteLen[0] = 0x80;
		//ByteLen[1] = 0x00;
		//write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_FLASH_DATA_LENGTH, (uint08 *)&ByteLen, 2);
	}

	return TRUE;
}

///////////////////////////////////////////////////////////////

void PushButtonGPIOProcess ()
{
	 uint08 Param[4];
	// Read PB button status from GPIO 15, 16, 17, 18, 19

	// Configure GPIO 15, 16, 17, 18, 19 as input
	Param[0] = 0;
	Param[1] = 0x50; // GPIO 15, 16 as input
	Param[2] = 0x15; // GPIO 17, 18, 19 as input
	Param[3] = 0;
	write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_GPIO_CONTROL, Param, 4);

	// Read PB (Not pressed PB read as 1, Pressed PB read as 0)
	// GPIO 16 is Right PB
	// GPIO 17 is Up PB
	// GPIO 18 is Down PB
	// GPIO 15 is Left PB
	// GPIO 19 is Select PB
	// READ GPIO input should read 3 bytes
	read_dpp3430_i2c (DPP3430_DEV_ADDR, READ_GPIO_INPUT, NULL, 0, Param, 3);
	// We ignore Byte 1 ==> Param[0]. don't have cared about GPIO
	// Byte 2 should be read as 0xC0, 1100,0000 as GPIO 16 (b(7)), 15 (B(6))
	// Bytes 3 should be read as 0x07, 0111 as GPIO 19 (b(2)), 18 (b(1)), 17 (b(0))
	if ((Param[1] & 0x80) == 0)
	{
		// We have GPIO 16 pressed: Right PB
		static uint08 itpg_select = TPG_SOLID_FIELD;

    if ( itpg_select == TPG_COLOR_BARS )
       itpg_select = TPG_SOLID_FIELD;
    else
       itpg_select++;
		dpp3430_config_tpg(itpg_select);
	}
	else
	if ((Param[1] & 0x40) == 0)
	{
		// We have GPIO 15 pressed: Left PB
	}
	else
	if ((Param[2] & 0x04) == 0)
	{
		// We have GPIO 19 pressed: Select PB
	}
	else
	if ((Param[2] & 0x02) == 0)
	{
		// We have GPIO 18 pressed: Down PB
		dpp3430_config_rgb();
	}
  else
	if ((Param[2] & 0x01) == 0)
	{
		// We have GPIO 17 pressed: Up PB
		dpp3430_config_splash(0);
	}

	return;
}
#endif // Not used



void ChangePicoResolution(uint16 HActive,uint16 VActive )
{
	Pico_HActive[0]=HActive%256;
	Pico_HActive[1]=HActive/256;	
	Pico_VActive[0]=VActive%256;
	Pico_VActive[1]=VActive/256;	
//
//	dpp3430_config_rgb();	
//        // If curtain is enabled, disable curtain
//      	if(DPP_is_curtain_enable())
//        	DPP_enable_curtain(FALSE);		

	DPP343x_DisplayRGBModeSet(TRUE);	// true for change pic343x to RGB input mode

}
