/*****************************************************************************
**
**             TEXAS INSTRUMENTS PROPRIETARY INFORMATION
**
**  (c) Copyright, Texas Instruments Incorporated, 2008
**      All Rights Reserved.
**
**  Property of Texas Instruments Incorporated. Restricted Rights -
**  Use, duplication, or disclosure is subject to restrictions set
**  forth in TI's program license agreement and associated documentation.
******************************************************************************/
/*************************************************************
* THIS PROGRAM IS PROVIDED "AS IS." TI MAKES NO WARRANTIES OR
* REPRESENTATIONS, EITHER EXPRESS, IMPLIED OR STATUTORY,
* INCLUDING ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR PURPOSE, LACK OF VIRUSES, ACCURACY OR
* COMPLETENESS OF RESPONSES, RESULTS AND LACK OF NEGLIGENCE.
* TI DISCLAIMS ANY WARRANTY OF TITLE, QUIET ENJOYMENT, QUIET
* POSSESSION, AND NON-INFRINGEMENT OF ANY THIRD PARTY
* INTELLECTUAL PROPERTY RIGHTS WITH REGARD TO THE PROGRAM OR
* YOUR USE OF THE PROGRAM.
*
* IN NO EVENT SHALL TI BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
* CONSEQUENTIAL OR INDIRECT DAMAGES, HOWEVER CAUSED, ON ANY
* THEORY OF LIABILITY AND WHETHER OR NOT TI HAS BEEN ADVISED
* OF THE POSSIBILITY OF SUCH DAMAGES, ARISING IN ANY WAY OUT
* OF THIS AGREEMENT, THE PROGRAM, OR YOUR USE OF THE PROGRAM.
* EXCLUDED DAMAGES INCLUDE, BUT ARE NOT LIMITED TO, COST OF
* REMOVAL OR REINSTALLATION, COMPUTER TIME, LABOR COSTS, LOSS
* OF GOODWILL, LOSS OF PROFITS, LOSS OF SAVINGS, OR LOSS OF
* USE OR INTERRUPTION OF BUSINESS.  IN NO EVENT WILL TI'S
* AGGREGATE LIABILITY UNDER THIS AGREEMENT OR ARISING OUT OF
* YOUR USE OF THE PROGRAM EXCEED FIVE HUNDRED DOLLARS
* (U.S.$500).
*
* Unless otherwise stated, the Program is written and copyrighted
* by Texas Instruments is distributed as "freeware."  You may,
* only under TI's copyright in the Program, use and modify the
* Program without any charge or restriction.  You may
* distribute to third parties, provided that you transfer a
* copy of this license to the third party and the third party
* agrees to these terms by its first use of the Program.  In
* jurisdictions in which use is not deemed acceptance of these
* terms, no license is granted and no use is permitted.  You
* must reproduce the copyright notice and any other legend of
* ownership on each copy or partial copy of the Program.
*
* You acknowledge and agree that the Program contains
* copyrighted material, trade secrets and other TI proprietary
* information and is protected by copyright laws,
* international copyright treaties, and trade secret laws, as
* well as other intellectual property laws.  You agree that in
* no event will you alter, remove or destroy any copyright
* notice included in the Program.  TI reserves all rights not
* specifically granted under this license.  Except as
* specifically provided herein, nothing in this agreement
* shall be construed as conferring upon you, by implication,
* estoppel, or otherwise, any license or other right under any
* TI patents, copyrights or trade secrets.
*************************************************************/

#ifndef __dpp3430
#define __dpp3430

#ifdef __cplusplus
extern "C" {
#endif

// DPP configuration functions
uint08 dpp3430_config_tpg(uint08 pattern_select);
uint08 dpp3430_config_splash(uint08 image_number);
void dpp3430_config_rgb(void);
uint08 dpp3430_config_tvp(void);
uint32 dpp3430_read_short_status();
uint08 dpp3430_read_OEM_ScratchPad ();
void PushButtonGPIOProcess ();

uint08 GetSplashScreenDimention (uint08 index, uint16 *x, uint16 *y);
void ChangePicoResolution(uint16 HActive,uint16 VActive );
void DPP343x_RGBBlackSreenSet(void);
void DPP343x_DisplayRGBModeSet(unsigned char bDispRGBMode);

//Curtain Functions
void DPP_enable_curtain(uint08 enable);
uint08 DPP_is_curtain_enable(void);
void DPP_set_curtaincolor(uint08 color);
uint08 Pad2000Used ();


typedef enum _LED_State_Type {
    LED_Off=0,
    LED_MHL_Mode,		
    LED_PICO343X_Debug_Mode,
    LED_PICO343X_Normal_Operation,    
    LED_MHL_VideoOn,
    LED_NONE
} LED_State_Type;

#define MAX_LED_NUMBER 1
#define MAX_LED_TIME 0xFFFF
#define PICO343X_DEBUG_MODE_TIME (KEY_POLL_TIME*2)  	// 100 ms x 2 = 200ms 
#define LED_MHL_MODE_TIME (KEY_POLL_TIME*10)  	// 100 ms x 10 = 500ms 
#define MIN_LED_TIME 0
#define LED1 0


extern void InputLEDFlash(unsigned char LedNum,unsigned short u16_time);
extern void Switch_LEDState(LED_State_Type state,unsigned char LedNum);
extern void LEDProcess(void);

extern void DAC3201_WriteI2C_Byte(uint08 RegAddr,uint08 ucdata);
extern void SetDAC3101DefaultRegisterValue(void);
extern void SetDAC3101AudioOn(unsigned char bMuteFlag);
extern void SetDAC3101Volume(unsigned char bInc);



// Sequence of executing Flash command
// Flash Data Type Select (DEh): Entire OEM Scratch Pad Set 0 0xB0
// Flash Data Length (DFh) Read Max 256 bytes
// Read Flash Start (E3h)
// Flash Data Length (DFh) Read Max 256 bytes
// Read Flash Continue (E4)



#define WRITE_INPUT_SOURCE_SELECT        0x05
#define WRITE_SOURCE_FORMAT_SELECT       0x07
#define WRITE_EXTERNAL_CHROMA_PROCESS    0x09
#define WRITE_TEST_PATTERN_SELECT        0x0B
#define WRITE_SPLASH_SCREEN_SELECT       0x0D
#define READ_SPLASH_SCREEN_HEADER        0x0F    // Read 13 bytes
#define WRITE_IMAGE_CROP                 0x10
#define WRITE_DISPLAY_SIZE               0x12
#define READ_DISPLAY_SIZE                0x13
#define WRITE_DISPLAY_IMAGE_ORIENTATION  0x14
#define WRITE_CURTAIN_CONTROL            0x16
#define READ_CURTAIN_CONTROL             0x17
#define WRITE_IMAGE_FREEZE               0x1A
#define WRITE_EXTERNAL_INPUT_IMAGE_SIZE  0x2E

#define WRITE_GPIO_CONTROL               0x31
#define WRITE_GPIO_OUTPUTS				 0x33
#define WRITE_SPLASH_SCREEN_EXECUTE      0x35
#define READ_GPIO_INPUT                  0x36

#define WRITE_LED_OUTPUT_CONTROL         0x50
#define WRITE_RGB_LED_ENABLE             0x52
#define WRITE_LED_CURRENT                0x54
#define WRITE_INTERNAL_VSYNC_RATE        0xB0
#define READ_SHORT_STATUS                0xD0
#define WRITE_LABB_CONTROL               0x80
#define READ_SYSTEM_SW_VERSION           0xD2
#define READ_ASIC_DEVICE_ID              0xD4
#define READ_DMD_ID                      0xD5   //(Randy Chen added on 12/6)
	// DMD ID 06 b0 00 26 for .2 wVGA
	// DMD ID 06 b0 00 16 for .3 720p

#define PAD_WRITE_REQUEST                0xeb
#define READ_PAD_ID                      0xed

#define PAD_2000_ID                      0xB1
#define PAD_2000_ID_OLD                  0xB0

#define PAD_2005_ID                      0xC0

#define WRITE_FLASH_DATA_TYPE_SELECT     0xDE
#define WRITE_FLASH_DATA_LENGTH          0xDF  // Length uint16: LSB, MSB
#define READ_FLASH_START                 0xE3
#define READ_FLASH_CONTINUE              0xE4
#define Write_Keystone_Correction_Control    0x88   //(Randy Chen added on 1/2)
#define Write_Keystone_Pitch_Angle           0xBB   //(Randy Chen added on 1/2)

#define NTSC_LANDSCAPE            0      // (720h*240v)
#define PAL_LANDSCAPE             1      // (720h*288v)

// test pattern defines
#define TPG_SOLID_FIELD           0
#define TPG_HORIZONTAL_RAMP       1
#define TPG_VERTICAL_RAMP         2
#define TPG_HORIZONTAL_LINES      3
#define TPG_DIAG_LINES            4
#define TPG_VERTICAL_LINES        5
#define TPG_GRID_LINES            6
#define TPG_CHECKER_BOARD         7
#define TPG_COLOR_BARS            8

// curtain color defines
#define CURTAIN_BLACK             0
#define CURTAIN_RED               1
#define CURTAIN_GREEN             2
#define CURTAIN_BLUE              3
#define CURTAIN_CYAN              4
#define CURTAIN_MAGENTA           5
#define CURTAIN_YELLOW            6
#define CURTAIN_WHITE             7

#define TIMER_VALUE 			  65535   // 1 MHz system clk so timer value is 65 msec ( 65535/1000000)

// Splash screen header

typedef struct 
{
    uint16  Image_width;    /**< width of image in pixels */
    uint16  Image_height;   /**< height of image in pixels */
    uint32  Byte_count;     /**< number of bytes starting at "data" */
    uint08  Pixel_format;   /**< format of pixel data */
                            /**< 0 = 24-bit unpacked: 0x00RRGGBB Not supported by DDP2230/DDPDDP243x*/
                            /**< 1 = 24-bit packed:   RGB 8-8-8 */
                            /**< 2 = 16-bit:          RGB 5-6-5   DDP3020 only */
                            /**< 3 = 16-bit:          YCrCb 4:2:2 DDP2230/DDPDDP243x only */
    uint08  Compression;    /**< compression of image */
                            /**< SPLASH_FORCE_UNCOMPRESSED  = uncompressed */
                            /**< SPLASH_FORCE_RLE           = RLE compressed */
                            /**< SPLASH_USER_DEFINED        = User Defined Compression */
                            /**< SPLASH_FORCE_RLE_2PIXEL    = RLE compressed 2Pixel */

    uint08  ByteOrder;      /**< 0 - pixel is 00RRGGBB - DDP3020 */
                            /**< 1 - pixel is 00GGRRBB - DDP2230/DDPDDP243x */
    uint08  ChromaOrder;    /**< Indicates chroma order of pixel data (DDP2230/DDPDDP243x only) */
                            /**< 0 - Cr is first pixel (0xYYRR) */
                            /**< 1 - Cb is first pixel (0xYYBB) */
} SPLASH_HEADER;

/////////////////////////////////////////////////////////
//The OEM Scratchpad block 3 holds three types of data:
//1.	The block header (only one)
//2.	Image header (one per image)
//3.	Image pixel data (one per image)
//
//The sizes can be computed as:
//1.	4(id) + 4(count) + (8 * num_images) bytes
//2.	12 + (16 * 4) = 76 bytes
//3.	image_height * image_width / 2 (bytes)

typedef struct osd_header_table
{
    uint32  size;           /* =sizeof(osd,#) */
    uint32  start;          /* =offsetof(osd,#) */
} SIZE_TABLE;                 /* =varying(count) */

typedef struct osd_header
{
    char       id[4];                    /* =set('OSDH') */
    uint32     count;                    /* =elementsof(osd) */
    SIZE_TABLE table[1];                 /* =varying(count) */
} OSD_HEADER;

enum OSD_FLAGS { SCALE_H = 1, SCALE_V = 2 };

typedef struct osd_image
{
    uint16  x;
    uint16  y;
    uint16  width;
    uint16  height;
    uint16  flags;
    struct color
    {
        uint08 red;
        uint08 green;
        uint08 blue;
        uint08 alpha;
    } palette[16];
    uint16  byte_count;
    uint08  pixels[1];        /* =varying(byte_count) no_pad_struct */
} OSD_IMAGE;


#ifdef __cplusplus		/* matches __cplusplus construct above */
}
#endif

#endif /* #ifndef __dpp3430 */

