#include "common.h"
#include "msp430x22x4.h"
#include "ddp343xEVM_pins.h"
#include "dpp343x.h"
#include "i2c_master.h"
#include "ddp343xEVM.h"

#include "TI_USCI_I2C_slave.h"

#include "Mhlrx.h"
#include "Mhlrx_reg.h"
#include "TimerProcess.h"

//#define _WITHOUT_DPP343X_ 

//===== UART Function =====
void PutChar(char CH);
void PutBin(char CH);
void Printf(const  char *Msg, ...);
void receive_cb(unsigned char receive);
void transmit_cb(unsigned char volatile *receive);
//void uart_transmit_cb(unsigned char volatile *byte);
void uart_transmit_cb(unsigned char volatile *byte);


//===== Keypad Function =====
void PwrKeyPolling(void);
void KeypadProcess(void);
void KeypadEvent(void);
void DPP343x_DisplayModeProcess(void);

//===== CAIC and LABB =====
//void CAIC_LABB_Polling(void);

#if 1
#define KEY_POLL_TIME (100/SYSTEM_TICK)	 // 100ms
#define _HDMI_DEBUG_

#ifdef  _HDMI_DEBUG_
volatile uint08 ucDebug = 0;
#endif


#ifdef _ENABLE_HDMI_INT_
volatile uint08 bHDMIINT = 0;
#endif


LED_State_Type	LEDStatus[MAX_LED_NUMBER];
unsigned char LEDFlag[MAX_LED_NUMBER];

volatile unsigned short ucTickCount=0;
volatile unsigned char UARTTXData = 0 ;
volatile unsigned char mUartCount;

#define DEBOUNS (20/SYSTEM_TICK)
volatile uint08 Input_pin_state = 0;
volatile uint08 Input_pin_count= 0;
volatile uint08 Input_pin_state_Old = 0;
volatile uint08 Input_Press_state = 0;
#endif

// global variables
uint08 current_st=0xff;
//uint08 CAIC_st;
//uint08 LABB_st;
volatile uint08 Do_Once = 1;

display_mode_t display_mode = disp_mode_splash;
display_mode_t old_display_mode = disp_mode_splash;
uint08 tpg_select = 0;
uint08 splash_image_select = 0;
uint08 flips = 0;
uint08 CurtainColor = CURTAIN_GREEN;
uint08 Version[16] = "v1.0.1";
uint16 DMDx, DMDy;

// This one is for PAD2005 LED current, but limited to 650 mA
uint16 led_drive_current_PAD2005_array[10] = {
                                     0x29,	    // 101 mA
                                     0x42,      // 163 mA
                                     0x5B,      // 255 mA
                                     0x74,      // 287 mA
                                     0x8D,      // 348 mA
                                     0xA1,      // 410 mA
                                     0xBF,      // 472 mA
                                     0xD8,      // 534 mA
                                     0xF1,      // 596 mA
                                     0x107 };   // 650 mA

uint08 pad2000_used = TRUE;

uint08 led_drive_current = 2;

// Keystone pitch angle
const uint16 keystone_angle_array[9] = {
                                     0xD800, 	//-40'
                                     0xE200, 	//-30'
                                     0xEC00, 	//-20'
                                     0xF600,	//-10'
                                     0x0000,	//  0'
                                     0x0A00, 	// 10'
                                     0x1400, 	// 20'
                                     0x1E00, 	// 30'
                                     0x2800 }; 	// 40'
volatile uint08 pitch_angle = 4;
uint08 plus_angle_max = 8;
uint08 minus_angle_max = 0;


// X is in micro second
// This function will wait for x number of micro seconds.
void Hold(uint32 x)
{
    volatile uint16 TimerVal, TimeDiff;
    volatile uint16 BaselineTimerVal = TAR;
    volatile uint16 tmp1, tmp2, i;
                  
    if (x > TIMER_VALUE)
    {
       tmp1 = (uint16) (x / TIMER_VALUE);  // # of 65 msec
       tmp2 = (uint16) (x % TIMER_VALUE);  // Remaining time
       
       for (i=0; i<tmp1; i++)
       {
		  TA0CTL |= TACLR;      // Clear the timer A 	
		  BaselineTimerVal = TAR;       	
          while (1)
          {
          	// get current timer value
        	TimerVal = TAR;
        	
        	 // check for Timer rollover since we baselined
        	if ( TimerVal > BaselineTimerVal )
            	TimeDiff = TimerVal - BaselineTimerVal;
        	else
	            TimeDiff = (TIMER_VALUE - BaselineTimerVal) + TimerVal;

    	    // if it takes more than n us then timeout
        	if ( TimeDiff >= (TIMER_VALUE-10) )
            	break;
          }
       }
    }  
    else
    {
    	tmp1 = 0;
    	tmp2 = (uint16) x;
    }
     
    TA0CTL |= TACLR;       
	BaselineTimerVal = TAR;
	     
    for (i=0; i<500; i++)
    {
        // get current timer value
        TimerVal = TAR;

        // check for Timer rollover since we baselined
        if ( TimerVal > BaselineTimerVal )
            TimeDiff = TimerVal - BaselineTimerVal;
        else
            TimeDiff = (TIMER_VALUE - BaselineTimerVal) + TimerVal;

        // if it takes more than n us then timeout
        if ( TimeDiff >= tmp2 )
            break;
    }
    
	return;	
}



/*----------------------------------------------------------------------------+
| Main Routine                                                                |
+----------------------------------------------------------------------------*/
void main( void )
{
	// Stop watchdog timer to prevent time out reset
	WDTCTL = WDTPW + WDTHOLD;

	Init_Ports();
	TI_UART_init(uart_transmit_cb);
	Init_TimerA1();
	Init_TimerB();	

  while (1) 
  {   
	PwrKeyPolling();

	if(current_st != 0)
	{
		if (check_I2C_Read_Req_polarity () != 0)
		{
		    // Read P1.3 as 1, then write to P1.0 as 1, No I2C access.
			P1OUT |= I2C_ACK_WRITE;
			continue;
		}
		else
		{
			//If Req is read as 0, write 0 to P1.0 and proceed.
			P1OUT &= ~I2C_ACK_WRITE;
		}

		// if current_st is power on state then to do everthing  
		ProcessMultiTimerTask();

		if(TimeOutCheck(eKeyPolling)==TRUE)
		{
			KeypadProcess();
			LEDProcess();	
			//CAIC_LABB_Polling();
			CreatTimerTask(eKeyPolling,KEY_POLL_TIME,SysTimerTask_OnceRun);	
		}	

		// We decide to poll I2C reading to IT6801 all time to detect HDMI signal presence..
		//if (display_mode == disp_mode_rgb)
		{
			if(TimeOutCheck(eIT6802Polling)==TRUE)
			{
				{
				#ifdef  _HDMI_DEBUG_
				if(ucDebug==0)
				#endif
					{
						IT6802_fsm();
					}
				}
			CreatTimerTask(eIT6802Polling,IT6802_LOOP_TIME,SysTimerTask_OnceRun);
			}
		}

		DPP343x_DisplayModeProcess();
	}
  }
}



/*----------------------------------------------------------------------------+
| System Initialization Routines.
+----------------------------------------------------------------------------*/
VOID Init_TimerA1(VOID)
{
#if 0	
  TA1CCTL0 = CCIE;                          // CCR0 interrupt enabled
  TA1CTL = TASSEL_1 + TACLR;                // ACLK, clear TAR
#else  
TACCTL0 = CCIE;                          // CCR0 interrupt enabled
TACTL = TASSEL_1 + TACLR;                // ACLK, clear TAR
#endif	
}
  
/////////////////////////////////////////////////////////////////////////////////////////
VOID Init_Ports(VOID)
{
    // Drive all I/O's as output-low, making sure there's no shoot-through current.  There 
    // should be no floating I/Os, to prevent unnecessary current draw.
    P1OUT   =   0;
    // P1SEL   =   MSPJTAG_TCK;
    // P1DIR   =   MSPJTAG_TCK;
    P1SEL   =   0;
    P1DIR   =   0;

    P2OUT   =   0;
    P2SEL   =   0;
    P2DIR   =   0;

    P3OUT   =   0;
    P3SEL   =   0;
    P3DIR   =   0;    

  // 1MHz main clock
  // check for valid calibration data
  // Update 06-04-2009: Check both cal bytes
  if ((CALDCO_1MHZ != 0xFF) || (CALBC1_1MHZ != 0xFF)) 
  {
    // Calibrate to 1 Mhz clock8
    BCSCTL1 = CALBC1_1MHZ;
    DCOCTL = CALDCO_1MHZ;
  }
  else 
  { 
    // calibration data is invalid
    BCSCTL1 = 0x86;
    DCOCTL = 0xCF;
  }
}

////////////////////////////////////////////////
// Timer0 A0 interrupt service routine.
//#pragma vector=TIMER0_A0_VECTOR
//__interrupt void TIMER0_A0_ISR(void)

#pragma vector=TIMERA0_VECTOR
__interrupt void TIMER0_A0_ISR(void)
{    
  int i=0;	
  // disable timer A interrupt to prevent re-entrance problems
  TA0CCTL0 &= ~CCIE;
   
  if ((P2IN & INIT_DONE))
  {
  	// Reset button is pressed, re init everything
    //P3OUT |= LED_CPU_ENA;
 	
	resetInit ();    
	 	
  	// Wait for init_done signal go low
  	// to prevent this service routine doing reset init again
  	// We wait for INIT_DONE go low
    while (P2IN & INIT_DONE) 
    {
    	if (i > 20)
    	  break;
    	// 100 ms delay
		Hold(100000);
		i++; 	
    } 
    
    //P3OUT &= ~LED_CPU_ENA;
  }  
   
  // re-enable timer A interrupt
  TA0CCTL0 = CCIE;
}

////////////////////////////////////////////////
// Port 1 interrupt service routine. This is for
// video decoder interrupt ISR

#pragma vector=PORT1_VECTOR
__interrupt void Port1_ISR(void)
{
//#if DECODER_CONFIG
#ifndef _ENABLE_HDMI_INT_   	
  uint08 locked;
#endif  
  uint08 active_interrupt = P1IFG;

#ifdef _ENABLE_HDMI_INT_
	if ((active_interrupt & IT6801_INTN_PIN) == IT6801_INTN_PIN)
	{
//		IT6802PowerHandler();
		bHDMIINT=1;	
	}

	P1IFG &= ~active_interrupt;
	
#else
          
  // make sure the video decoder has issued the interrupt
  if ((active_interrupt & AVID_IRQ) != AVID_IRQ)
    return;

  // are we even using the video decoder?
  if (display_mode == disp_mode_656) 
  {
    read_i2c_1byte(TVP5150_DEV_ADDR, 0xc0, &locked);
    
    // clear the interrupts
    write_i2c_1byte(TVP5150_DEV_ADDR, 0xc0, locked);

    if ( locked & BIT7 ) 
    {
      P1IFG = 0;
      // video signal is locked, so maybe it was just a transient
      return;
    } 
  } 
  else 
  {
    // somehow this was reached erroneously
    // turn off the outputs and interrupts
    disable_tvp5150();
  }
#endif  
}

///////////////////////////////////////////////
// Port 2 interrupt service routine for button
// press on EVM

#pragma vector=PORT2_VECTOR
__interrupt void Port2_ISR(void)
{
	volatile uint32 i;
	uint08 active_interrupt = P2IFG;
	  	
    // Indicating we got a button interrupt
    // Enable the LED
    //P3OUT |= LED_TVP_ENA;
          	  	
	// Push buttons triggered the interrupt
	P2IFG &= ~active_interrupt;
	process_button(active_interrupt);
	
	// Clear the button press LED
    //P3OUT &= ~LED_TVP_ENA;
}

////////////////////////////////////////////////////////////////
// I2C Write N bytes Param to DPP

void write_dpp3430_i2c(uint08 addr, uint08 subaddr, uint08 *Param, uint08 ParamSize)
{
  uint08 status, i, j;
  uint08 i2c_array[12]; // Params max size cap at 12 bytes
  
  // clear fault indicator LED for this transaction
  //P3OUT &= ~LED_IIC_FAULT;

   if (ParamSize > 12)
  {
      //P3OUT |= LED_IIC_FAULT;
      return;
  }

  j=0;
  i2c_array[j] = subaddr;

  if (ParamSize != 0)
  {
	j++;
	for (i=0; i<ParamSize; i++)
	{
		i2c_array[j] = *(Param + i);
		j++;
	}
  }

  status = I2C_PolledMasterWrite(addr, i2c_array, ParamSize+1);
  
  // flag an error if necessary
  if (status == I2C_NO_ACK)
  {
    //P3OUT |= LED_IIC_FAULT;
  }

  return;
}

/////////////////////////////////////////////////////////////////
// I2C read N bytes from DPP
#define READ_SIZE    64

void read_dpp3430_i2c(uint08 addr, uint08 subaddr, uint08* Param, uint08 ParamSize, uint08 *Data, uint08 DataSize)
{
  uint08 i2c_array[READ_SIZE];
  uint08 status, i, j;
  
  // clear fault indicator LED for this transaction
  //P3OUT &= ~LED_IIC_FAULT;

  if (Data == NULL || ParamSize > 12 || DataSize > READ_SIZE)
  {
      //P3OUT |= LED_IIC_FAULT;
      return;
  }

  // setup the read request as I2C Write
  // Addr, Opcode/SubAddr, Param
  j = 0;
  i2c_array[j] = subaddr;

  if(ParamSize != 0)
  {
	j++;
	for (i=0; i < ParamSize; i++)
	{
		i2c_array[j] = *(Param + i);
		j++;
	}
  }

  status = I2C_PolledMasterWrite(addr, i2c_array, ParamSize+1);
  
  // flag an error if necessary
  if (status == I2C_NO_ACK) 
  {
    //P3OUT |= LED_IIC_FAULT;
    return;
  }
    

  // perform the read and read response
  addr = addr + 1;
  status = I2C_PolledMasterRead(addr, i2c_array, DataSize);
  
  // flag an error if necessary
  if (status == I2C_NO_ACK) 
  {
    //P3OUT |= LED_IIC_FAULT;
    return;
  }
    
  for (i=0; i<DataSize; i++)
  {
	  *(Data + i) = i2c_array[i];
  }

  return;
}

/////////////////////////////////////////////////////////////////
// Write 1 byte to TVP

void write_i2c_1byte(uint08 addr, uint08 subaddr, uint08 data)
{
  uint08 status;
  uint08 i2c_array[4];
  
  // clear fault indicator LED for this transaction
  //P3OUT &= ~LED_IIC_FAULT;

  i2c_array[0] = subaddr;
  i2c_array[1] = data;
  status = I2C_PolledMasterWrite(addr, i2c_array, 2);

  // flag the error if necessary
  if (status == I2C_NO_ACK)
    P3OUT |= LED_IIC_FAULT;
}

/////////////////////////////////////////////////////////////////
// Read 1 byte from TVP

uint08 read_i2c_1byte(uint08 addr, uint08 subaddr, uint08* data)
{
/**
 * Read one byte of data on IIC bus
 * 
 * @return  0 - no errors
 *          1 - IIC communication failed
 *
 */

  uint08 status = PASS;
  
  // clear fault indicator LED for this transaction
  //P3OUT &= ~LED_IIC_FAULT;

  status = I2C_PolledMasterWrite(addr, &subaddr, 1);
  // no sense continuing if the slave does not respond
  if (status == I2C_NO_ACK) 
  {
    //P3OUT |= LED_IIC_FAULT;
    return 1;
  }
  
  status = I2C_PolledMasterRead (addr, data, 1); 
  // flag the error if necessary
  if (status == I2C_NO_ACK) 
  {
  	//P3OUT |= LED_IIC_FAULT;
  	return 1;
  }

  return 0;
}

/////////////////////////////////////////////////////////////////
// Process EVM Button action

void process_button(uint08 active_interrupt)
{	  	
  // Process push button functionality.
  switch (active_interrupt) 
  {
    case BTN_UP:
    case BTN_DOWN:		
		process_display_adjust(active_interrupt);
		break;
		
    case BTN_LEFT:
        // Volume adjustment is only available when input source is RGB.
//          if (display_mode == disp_mode_rgb)
//          {
                SetDAC3101Volume(0);
//          }
//          else
//          {
                process_display_adjust(active_interrupt);
//          }
        		break;

    case BTN_RIGHT:
        // Volume adjustment is only available when input source is RGB.
//	        if (display_mode == disp_mode_rgb)
//    		{
            	SetDAC3101Volume(1);
//      	}
//      	else
//      	{
            	process_display_adjust(active_interrupt);
//      	}
    	    	break;
      
    case BTN_SEL:
      //dpp3430_read_OEM_ScratchPad ();

      if ( CurtainColor > CURTAIN_WHITE ) 
          CurtainColor = CURTAIN_BLACK;
  
  	  DPP_set_curtaincolor(CurtainColor);
  	  CurtainColor++;	                     	  	          
      break;
      
    default:
      return;
  }
}

/////////////////////////////////////////////////////////////////
// Adjust display

void process_display_adjust(uint08 button)
{
  uint08 Param[8];
  	
  // Process UP,DOWN,LEFT,RIGHT button functionality	
  
  switch (button) 
  {
    case BTN_UP:  // aka source select
#if DECODER_CONFIG    
      if (display_mode == disp_mode_656)
#else
      if (display_mode == disp_mode_rgb)
#endif      
      {
        display_mode = disp_mode_splash;
      }
      else 
      {
        display_mode++;        
      }
           
      // call procedures to configure new source
      if (display_mode == disp_mode_splash)
      {
      		//dpp3430_config_splash(splash_image_select);        
		DPP343x_DisplayRGBModeSet(FALSE);	// FALSE for change pic343x to Splash mode

      }
#if DECODER_CONFIG   
      else 
      if (display_mode == disp_mode_656)
      {      	
        // if the return value is non-zero, there is not a source present
        //  or the source is unrecognized by the video decoder       
        if (dpp3430_config_tvp()) 
        {
          disable_tvp5150();
        }
      } 
#else      
	  else 
      if (display_mode == disp_mode_rgb)
      {
	        //dpp3430_config_rgb();
		DPP343x_DisplayRGBModeSet(TRUE);	// true for change pic343x to RGB input mode
    
      }
#endif        	       	
      else 
      {
        display_mode = disp_mode_tpg;
        dpp3430_config_tpg(tpg_select);
      }
      break;

    case BTN_DOWN:  // flips image
      if ( flips > 6 ) 
          flips = 0;

      // write long and short flips, 0- No Flip, 2 - Long flip, 4 - Short flip, 6 - Long and Short flips
	  Param[0] = flips;
	  write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_DISPLAY_IMAGE_ORIENTATION, Param, 1);
      flips += 2;

      if (display_mode == disp_mode_splash)
      {
    	  uint08 i;
    	  // For Splash screen to flip axis, need to send execute
    	  // Write Splash screen execute
    	  write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_SPLASH_SCREEN_EXECUTE, NULL, 0);
    	  for (i=0; i<2; i++)
    		  Hold (500000);
      }

      break;

    case BTN_LEFT: // Display test patterns and Splash screens
      if ( display_mode == disp_mode_tpg ) 
      {      	
        if ( tpg_select == TPG_COLOR_BARS )
          tpg_select = TPG_SOLID_FIELD;
        else
          tpg_select++;
        
        dpp3430_config_tpg(tpg_select);        
      } 
      else 
      if (display_mode == disp_mode_splash) 
      {
        // check bounds
        if (splash_image_select >= (NUM_SUPPORTED_SPLASH-1))
        {
          splash_image_select = 0;
        }
        else
        {
          splash_image_select++;
        }

        dpp3430_config_splash(splash_image_select);
      }
      break;
      
    case BTN_RIGHT:  // Cycle LED current to make pseudo brightness control
      led_drive_current++;
      // check bounds
      if ( led_drive_current > 9 )
          led_drive_current = 0;
      
      //pad2000_used = Pad2000Used ();
      // Update LED current RGB
      
      Param[0] = (uint08) (led_drive_current_PAD2005_array[led_drive_current]); // RED LSB
      Param[1] = (uint08) (led_drive_current_PAD2005_array[led_drive_current] >> 8); // RED MSB

      Param[2] = (uint08) (led_drive_current_PAD2005_array[led_drive_current]); // Green LSB
      Param[3] = (uint08) (led_drive_current_PAD2005_array[led_drive_current] >> 8); // Green MSB

      Param[4] = (uint08) (led_drive_current_PAD2005_array[led_drive_current]); // Blue LSB
      Param[5] = (uint08) (led_drive_current_PAD2005_array[led_drive_current] >> 8); // Blue MSB
      
  	  write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_LED_CURRENT, Param, 6);    
           	                    
      break;
    default:
      return;
  }
}

////////////////////////////////////////////////////////

void global_selection_init ()
{
  //Select 0th Splash image at power up. 
  //Select default LED current setting at power up
  tpg_select = TPG_SOLID_FIELD;
  splash_image_select = 0;
  led_drive_current = 2;     
  display_mode = disp_mode_splash;   
  pitch_angle = 4;

}

////////////////////////////////////////////////////////
// Disable video decoder

void disable_tvp5150(void)
{
#ifndef _ENABLE_HDMI_INT_  
  // disable the TVP interrupt
  P1IE = 0;
#endif


#ifdef ENABLE_TVP5151    
  write_i2c_1byte(TVP5150_DEV_ADDR, 0x03, 0); 
  Hold(100000);
  // assert the device power down to reduce power consumption
  P1OUT &= ~TVP5150_PDz;
#endif  
}

/////////////////////////////////////////////////////////

void resetInit (void)
{          	    	      
  	  // Clears all other pending interrupt before proceeding after power-up
      P1IFG = 0;  
      P2IFG = 0;
#ifndef _REAL_TIME_
      //Enable Interrupt for push buttons once power is up
      P2IE = (BTN_SEL | BTN_UP | BTN_LEFT | BTN_DOWN | BTN_RIGHT);      
  	  // Pushbuttons set for edge interrupt. ON/OFF is not a push button but a switch so taken care of by pulling
  	  P2IES = (BTN_SEL | BTN_RIGHT | BTN_LEFT | BTN_DOWN | BTN_UP);
#endif  	  	

#ifdef _ENABLE_HDMI_INT_
	P1IE = IT6801_INTN_PIN;
	P1IES = IT6801_INTN_PIN;
#endif	
	
  	  global_selection_init ();     

#if 1
	//TI_UART_init(uart_transmit_cb);
	Init_TimerA1();
	Init_TimerB();	
#endif

  	  // enable global interrupts
  	  __bis_SR_register(GIE);


	//Printf("================resetInit( )================ \n");
	
#if 1	
	IT6802_fsm_init();	 
	
	#ifdef _REAL_TIME_
	CreatTimerTask(eKeyPolling,KEY_POLL_TIME,SysTimerTask_OnceRun);	
	CreatTimerTask(eIT6802Polling,IT6802_LOOP_TIME,SysTimerTask_OnceRun);			
	#endif	
	
#endif
}

/////////////////////////////////////////////////////////
// Power up the MSP430 and do initialization

void powerup(void)
 {
 	  volatile uint32 i;

      i = 0;
       // set appropriate I/O to outputs
#ifdef _IT680x_
      //P1DIR = 0xF2;		// 0 for input , 1 for output
      P1DIR = 0xF3;		// 0 for input , 1 for output
#else
#if DECODER_CONFIG
      P1DIR = 0xF7;
#else
      P1DIR = 0xFF;
#endif
#endif

      P2REN=0xC0;
      P2SEL &= ~BIT6;
      P2SEL &= ~BIT7;

      P2OUT = MSP_PROJ_ON; 	// to avoid  projector power off 

      P2DIR = 0xC0;

      P3DIR = 0xF6;

      // turn on projector power
      P2OUT = MSP_PROJ_ON;
            
      // Write 1 to upper 4 bits to turn off LEDs since it's inverted.
      P3OUT = 0x00;
	  // HDMI detection LED Always Off during init
	  P3OUT |= LED_IT6802_ON;
          
      // Wait for 500 us
      Hold(500);
      //P2OUT |= MSP_PARKZ;  // Power good to DPP ASIC 
      
#if DECODER_CONFIG
      dpp3430_Init_Decoder ();
#else               
  	  // enable DVI board
      P3OUT |= MSP_DVI_PDZ;
#endif

#ifdef _IT680x_
	// powerup IT6801
	P1OUT &= ~IT6801_RSTN_PIN; // TVP5150_RSTz and XCVR_OEZ are the same pin.
	// wait for 100 ms to de-assert TVP reset
	Hold(100000); 
	P1OUT |= IT6801_RSTN_PIN;
#endif
                        
      // Wait for DPP finish init? We can send I2C command to DPP as soon as power up
      // Wait for DPP init done.
      i = 0;
      while ( (P2IN & INIT_DONE) == 0 ) 
      {
      	if (i >= 5)
      	  break;
        i++;
        Hold (20000);
      }
	 
      // i2c controller setup
      I2C_Master_Init();

      // Wait for I2C ready
      Hold(20000);
            
      // Clears all other pending interrupt before proceeding after power-up
      P1IFG = 0;  
      P2IFG = 0;
#ifndef _REAL_TIME_
      //Enable Interrupt for push buttons once power is up
      P2IE = (BTN_SEL | BTN_UP | BTN_LEFT | BTN_DOWN | BTN_RIGHT);      
  	  // Pushbuttons set for edge interrupt. ON/OFF is not a push button but a switch so taken care of by pulling
  	  P2IES = (BTN_SEL | BTN_RIGHT | BTN_LEFT | BTN_DOWN | BTN_UP);
#endif	  

#ifdef _ENABLE_HDMI_INT_
	P1IE = IT6801_INTN_PIN;
	P1IES = IT6801_INTN_PIN;   
#endif	
      // setup for Timer A - 65 msec timeout rate
      // TA0CCR0  = 65535;  // 0xffff
      // setup for Timer A - 10 msec timeout rate
      TA0CCR0  = 10082; 
      TA0CTL   = TASSEL_2 + MC_1;
        
      //Enable Timer interrupt            
      TA0CCTL0 = CCIE;
      
  	  global_selection_init ();      
  	  // enable global interrupts
  	  __bis_SR_register(GIE);
  	  // Delay 100 ms
  	Hold(100000);
  	SetDMD_size();  
  	  // Delay 10 ms
  	//Hold(10000);
  	//SetKeystone_TR_OFS();
    // Delay 5 ms
  	//Hold(5000);
 }      	

//////////////////////////////////////////////////////
// Power down the projector

void powerdown(void)
{  
   uint08 Param[2];

  // enable interrupts to allow I2C to work
  __bis_SR_register(GIE);

  // Turn off LEDs. Write RGB LED Disable 
  Param[0] = 0;
  write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_RGB_LED_ENABLE, Param, 1);
    
  // Disable timer interrupt
#if 0  
  TA1CCTL0 = 0;
#else  
  TACCTL0 = 0;	//for msp2274
#endif  

  #ifndef _ENABLE_HDMI_INT_  
  // video decoder interrupt disable
  P1IE = 0;
  #endif
  // buttonn interrupt disable
  P2IE = 0;
  
  // disable global interrupts
  __bic_SR_register(GIE);
    
  // turn off projector power
  P2OUT &= ~MSP_PROJ_ON;

  // Delay 200 ms = 200000
  Hold(200000);
           
#ifdef ENABLE_TVP5151             
  P1OUT &= ~TVP5150_RSTz; // TVP5150_RSTz and XCVR_OEZ are the same pin.
#endif  
  
  //Disable other button interrupts
  P2IE &= ~(BTN_SEL | BTN_RIGHT | BTN_LEFT | BTN_DOWN | BTN_UP);
    
  // set I/Os to inputs except PARKz
  P1DIR = 0x02;  // Parkz needs to be directed as output to be sure PAD device powered down.
  P2DIR = 0;
  P3DIR = 0x40;
   
  P1OUT = 0;
  P2OUT = 0;
  P3OUT = 0x40;
}

////////////////////////////////////////////////////
// Read PowerOnOff switch polarity

uint08 check_PowerOnOff_polarity()
{
    uint08 pin_state = ACTIVE_LOW;
	pin_state = (P3IN & SW_ON_OFF);
	
    if (pin_state == ACTIVE_LOW)
    {
        pin_state = 0;        
    }
    else
    if (pin_state == ACTIVE_HIGH)
    {
        pin_state = 1;      
    }

    return pin_state;
}
void DAC3201_WriteI2C_Byte(unsigned char  RegAddr,unsigned char  ucdata)	
{
  uint08 status;
  uint08 i2c_array[4];
  
  // clear fault indicator LED for this transaction
//  P3OUT &= ~LED_IIC_FAULT;
//  P3OUT &= ~LED_TVP_ENA;  


  i2c_array[0] = RegAddr;
  i2c_array[1] = ucdata;
  status = I2C_PolledMasterWrite(0x30, i2c_array, 2);

  // flag the error if necessary
  if (status == I2C_NO_ACK){
//    P3OUT |= LED_IIC_FAULT;
//    P3OUT |= LED_TVP_ENA;
  }
}



//==========================================================
// Put a character to UART
//==========================================================
void PutChar(char CH)
{
	UCA0CTL1 &= ~UCSWRST;                     // **Initialize USCI state machine**
	mUartCount=1;		

	UARTTXData=CH;	

	IE2 |= UCA0TXIE;                        // Enable USCI_A0 TX interrupt

	while(mUartCount);
}
//==========================================================
// Put a number to UART
// Input : a number 0 to 15
//==========================================================
void PutBin(char CH)
{
	if (CH > 9)	CH += 'A' - 10;
	else			CH += '0';
	PutChar(CH);
	return;
}
//==========================================================
// Put a message to UART
//==========================================================
// '\n': new line
// "%d": int & dec
// "%u": unsigned int & dec
// "%c": unsigned char & dec
// "%x": unsigned int & hex, default
// "%X": unsigned char & hex
//==========================================================
void Printf(const char *Msg, ...)
{
	unsigned char CH;
	unsigned short  Val;
	unsigned char *Ptr;
	Ptr = (unsigned char *)&Msg + 2;
	


  
	while(*Msg)
		{
			switch(*Msg)
				{
					case '\n':
						PutChar('\r');
						PutChar(*Msg++);
						break;

					case '%':
						Msg++;
						switch(*Msg)
							{
								case 'd':
									Val = *(unsigned short *)Ptr;
									Ptr += 2;
									if (Val & 0x8000)
										{
											PutChar('-');
											Val = -Val;
										}
									if (Val >= 10000) PutBin(Val / 10000);
									if (Val >= 1000) PutBin(Val / 1000 % 10);
									if (Val >= 100) PutBin(Val / 100 % 10);
									if (Val >= 10) PutBin(Val / 10 % 10);
									PutBin(Val % 10);
									break;

								case 'u':
									Val = *(unsigned short *)Ptr;
									Ptr += 2;
									if (Val >= 10000) PutBin(Val / 10000);
									if (Val >= 1000) PutBin(Val / 1000 % 10);
									if (Val >= 100) PutBin(Val / 100 % 10);
									if (Val >= 10) PutBin(Val / 10 % 10);
									PutBin(Val % 10);
									break;

								case 'c':
									CH = *Ptr++;
									if (CH >= 100) PutBin(CH / 100);
									if (CH >= 10) PutBin(CH / 10 % 10);
									PutBin(CH % 10);
									break;

								case 'x':
								default:
									CH = *Ptr++;
									PutBin(CH >> 4);
									PutBin(CH & 0xF);
									CH = *Ptr++;
									PutBin(CH >> 4);
									PutBin(CH & 0xF);
									break;

								case 'X':
									CH = *(unsigned char *)Ptr; 
									Ptr += 2;

									PutBin(CH >> 4);
									PutBin(CH & 0xF);
									break;
							}
						Msg++;
						break;

					default:
						PutChar(*Msg++);
						break;
				}
	}
	//EA=TRUE;
	return;
}


//void uart_transmit_cb(unsigned char volatile *byte){
void uart_transmit_cb(unsigned char volatile *byte){	
  *byte = UARTTXData;
}



/*----------------------------------------------------------------------------+
| System Initialization Routines.
+----------------------------------------------------------------------------*/
void Init_TimerB(void)
{
	WDTCTL = WDTPW + WDTHOLD;                 // Stop WDT
	TB0CCR0  = TIMERB_INIT_VALUE;	

	TB0CTL   = TBSSEL_2 + MC_1;
	TB0CCTL0 = CCIE;

	ucTickCount=0;
	initTimerTask();
}


// Timer B0 interrupt service routine
#pragma vector=TIMERB0_VECTOR
__interrupt void TIMERB_ISR (void)
{
// disable timer B interrupt to prevent re-entrance problems
TB0CCTL0 &= ~CCIE;
//P3OUT=~P3OUT;
ucTickCount++; 
KeypadEvent();

// re-enable timer B interrupt
TB0CCTL0 = CCIE;
}


//===============================================================
void InputLEDFlash(unsigned char  LedNum,unsigned short u16_time)
{
	if(u16_time == 0)
	{
		switch(u16_time == MIN_LED_TIME)
		{
			case LED1:
				// LED 1 Always Off
				P3OUT |= LED_IT6802_ON;						
				LEDFlag[LedNum]= 0;
				
				break;
		}
	}
	else	 if(u16_time == MAX_LED_TIME)
	{
		switch(LedNum)
		{
			case LED1:
				// LED 1 Always ON 
				P3OUT &= ~LED_IT6802_ON;				
				LEDFlag[LedNum]= 1;				
				break;
		}
	}
	else
	{
		switch(LedNum)
		{
			case LED1:
				// LED 1 flash 				
				 if(TimeOutCheck(eLED1Ctrl)==TRUE)
				 {
					//LED1=~LED1;
					if(LEDFlag[LedNum])
					{
						P3OUT |= LED_IT6802_ON;						
						LEDFlag[LedNum]= 0;
					}
					else
					{
						P3OUT &= ~LED_IT6802_ON;				
						LEDFlag[LedNum]= 1;				
					}
					
					CreatTimerTask(eLED1Ctrl,u16_time,SysTimerTask_OnceRun);										
				 }				
				break;
		}
	}
}

void Switch_LEDState(LED_State_Type state,unsigned char  LedNum)
{	
	LEDStatus[LedNum]=state;	
	
	switch(LEDStatus[LedNum])
	{

		case LED_Off:
			InputLEDFlash(LedNum,MIN_LED_TIME);		
			break;
			
		case LED_MHL_Mode:
			CreatTimerTask(eLED1Ctrl,LED_MHL_MODE_TIME,SysTimerTask_OnceRun);	
			break;
							
		case LED_PICO343X_Debug_Mode:
			CreatTimerTask(eLED1Ctrl,PICO343X_DEBUG_MODE_TIME,SysTimerTask_OnceRun);		
			break;

		case LED_PICO343X_Normal_Operation:

			if(display_mode == disp_mode_rgb)
			{
				if(IsVideoOn() == TRUE)
				{
					InputLEDFlash(LedNum,MAX_LED_TIME);
					LEDStatus[LedNum]= LED_MHL_VideoOn;
				}
				else
				{
			       	CreatTimerTask(eLED1Ctrl,LED_MHL_MODE_TIME,SysTimerTask_OnceRun);	
					LEDStatus[LedNum]= LED_MHL_Mode;				
				}
			}
			else
			{
					InputLEDFlash(LedNum,MIN_LED_TIME);		
					LEDStatus[LedNum]= LED_MHL_Mode;	
			}

			break;			
							
		case LED_MHL_VideoOn:
			InputLEDFlash(LedNum,MAX_LED_TIME);		
			break;
	}	
}


void LEDProcess(void)
{
	unsigned char  uc;	

	for(uc=0;uc<MAX_LED_NUMBER;uc++)
	{

		switch(LEDStatus[uc])
		{
			case LED_Off:
				// LED 1 Always Off
				P3OUT |= LED_IT6802_ON;						
				LEDFlag[uc]= 0;					
				break;

			case LED_MHL_Mode:
				InputLEDFlash(uc,LED_MHL_MODE_TIME);		
				break;				
								
			case LED_PICO343X_Debug_Mode:
				InputLEDFlash(uc,PICO343X_DEBUG_MODE_TIME);		
				break;
								
			case LED_MHL_VideoOn:		
				// LED 1 Always ON 
				P3OUT &= ~LED_IT6802_ON;				
				LEDFlag[uc]= 1;					
				break;
		}
	}	
}

void PwrKeyPolling(void)
{

	uint08 NewCurrent_st=0;
	
#ifndef 	_WITHOUT_DPP343X_
    //If current state is power down, power off the projector.
    //If pin state is high, power on. 

	NewCurrent_st = check_PowerOnOff_polarity ();	

	if(current_st != NewCurrent_st )	
	{
		current_st = NewCurrent_st;

		//Printf("   PowerOnOff Polarity Change   \n\r");    
		
		if(current_st == 0) 		   
		{
			if (!Do_Once)
			{
			powerdown();    	
			//Printf("   powerdown   \n\r");    						
			}			
			Do_Once = 1;    
		} 
		else 
		{
			if (Do_Once)
			{
				powerup();

				//Printf("   powerup   \n\r");
				IT6802_fsm_init();		
				SetDAC3101DefaultRegisterValue();	
				SetDAC3101AudioOn(FALSE);	// Turn OFF Audio	    
				Do_Once = 1;	
				
				#ifdef _REAL_TIME_
					CreatTimerTask(eKeyPolling,KEY_POLL_TIME,SysTimerTask_OnceRun);	
					CreatTimerTask(eIT6802Polling,IT6802_LOOP_TIME,SysTimerTask_OnceRun);			
				#endif   
				P3OUT |= LED_IT6802_ON;

  			
			}
			else
			{
				// LED off
				P3OUT |= LED_IT6802_ON;
			}
			Do_Once = 0;
		}	
	}
		



#endif	
}


void KeypadProcess(void)
{
	Input_pin_state = (P2IN);
	
	//Printf("123 Input_pin_state = %X \n\r",Input_pin_state);

	if(Input_pin_state==0x5F)	// all key release 
	{
		Input_pin_count=0;
		switch(Input_Press_state)
		{
			case BTN_UP:	
			case BTN_DOWN:	
			case BTN_LEFT:	
			case BTN_RIGHT:	
			case BTN_SEL:	
				{
					process_button(Input_Press_state);
					Input_Press_state=0;				

					//P3OUT &= ~LED_IIC_FAULT;
					//P3OUT &= ~LED_TVP_ENA;
					break;
				}
			
			case 0x53:	
				{
					Input_Press_state=0;
					
					#ifdef  _HDMI_DEBUG_					
						ucDebug = ~(ucDebug);					
						if(ucDebug==0)
						{
							//Printf("Normal Operation ...\r\n");
							Switch_LEDState(LED_PICO343X_Normal_Operation, LED1);						
							
						}
						else		
						{

							Switch_LEDState(LED_PICO343X_Debug_Mode, LED1);						
							//Printf("IT6801 debuging ...\r\n");
						}
					#endif
					
					break;						

				}

			case BTN_SEL_RIGHT:	// Press BTN_SEL+BTN_RIGHT for increasing keystone pitch angle
				 SetKeystone_Angle(1);
				 Input_Press_state=0;	// Execute SetKeytone_Angel() once then break.
				 break;
			
			case BTN_SEL_LEFT:	// Press BTN_SEL+BTN_LEFT for decreasing keystone pitch angle
				 SetKeystone_Angle(0);
				 Input_Press_state=0;	// Execute SetKeytone_Angel() once then break.
				 break;
			
			default:
				break;
										
		}	
	}
	
}
void KeypadEvent(void)
{
	Input_pin_state = (P2IN);
	
	//Printf("123 Input_pin_state = %X \n\r",Input_pin_state);

	if(Input_pin_state==0x5F)	// all key release 
	{

		Input_pin_count=0;
	
	}		
	else
	{
		if(Input_pin_state==Input_pin_state_Old)
		{
			Input_pin_count++;
			
		        if(Input_pin_count >DEBOUNS)
		        {
				//Printf("456 Input_pin_state = %X \n\r",Input_pin_state);
				switch(Input_pin_state)
				{
					case 0x5E:	Input_Press_state=BTN_UP;		break;
					case 0x5D:	Input_Press_state=BTN_DOWN;	    break;
					case 0x5B:	Input_Press_state=BTN_LEFT;		break;
					case 0x57:	Input_Press_state=BTN_RIGHT;	break;
					case 0x4F:	Input_Press_state=BTN_SEL;		break;
					case 0x53:	Input_Press_state=0x53;			break;	// Debug mode: I2C stop polling IT6801
					case 0x47:	Input_Press_state=BTN_SEL_RIGHT;break;	// Increasing keystone pitch angle
					case 0x4B:	Input_Press_state=BTN_SEL_LEFT;	break;	// Decreasing keystone pitch angle
				}			

			}
		}	
		else
			{
				Input_pin_count=0;
			}
		
	}	
	
	Input_pin_state_Old=Input_pin_state;

	
}


void DPP343x_DisplayModeProcess(void)
{
	if(display_mode!=old_display_mode)
	{  						
		if(display_mode == disp_mode_rgb)
		{
			if(ucDebug==0)
			{
				if(IsVideoOn() == TRUE)
				{
					dpp3430_config_rgb();	
				}
				else
				{
					//display_mode = disp_mode_splash;
					
					DPP343x_RGBBlackSreenSet();							
					Switch_LEDState(LED_PICO343X_Normal_Operation, LED1);											
				}
			}
			else		
			{
				Switch_LEDState(LED_PICO343X_Debug_Mode, LED1);					
				//Printf("IT6801 debuging ...\r\n");
			}			
		}

		if(display_mode == disp_mode_splash)
		{		
			//Printf("disp_mode_splash \r\n");
			Switch_LEDState(LED_Off, LED1);					
			dpp3430_config_splash(splash_image_select);
		}			
		else if(display_mode == disp_mode_tpg)
		{
			//Printf("disp_mode_tpg \r\n");
			Switch_LEDState(LED_Off, LED1);				
		}
		
		old_display_mode=display_mode;
	}
}

void DPP343x_RGBBlackSreenSet(void)
{
	if(display_mode == disp_mode_rgb)
	{
		DPP_enable_curtain(TRUE);
	}
}


void DPP343x_DisplayRGBModeSet(unsigned char bDispRGBMode)
{
	DPP_enable_curtain(TRUE);
	
	// call procedures to configure new source
	if (bDispRGBMode == TRUE)
	{
		display_mode = disp_mode_rgb;
		old_display_mode = disp_mode_splash;
	}
	else  
	{
		display_mode = disp_mode_splash; 		
	}
}
//============================================================================
#define INDEX_MAX_VOL 5
volatile unsigned char  ucDACVolume=INDEX_MAX_VOL;
const unsigned char  acDAC3101_Volume[]=
{0x80,0xC0,0xE0,0x00,0x18,0x30};	// -64dB , -32dB, -16dB, 0dB, 12dB, 24dB


static const REGPAIR acDAC3101_Audio_MuteOn[] =
{
	//#			--------------------------------------------------------------- page 0 is selected 
	{ 0x00,0x00},
	{ 0x41,0x80},			// Left Volume
	{ 0x42,0x80},			// Right Volume
//	{ 0x40,0x0C},		// Volume Control Mute On
	{0xFF,0xFF}	
};


static REGPAIR acDAC3101_USB_Init[] =
{
	//#			--------------------------------------------------------------- page 0 is selected 
	{ 0x00,0x00},
	{ 0x01,0x01},	
	//#			 s/w reset
	//> 01
	//#			 PLL_clkin = BCLK,codec_clkin = PLL_CLK
	{ 0x04,0x07},
	{ 0x05,0x91},
	{ 0x06,0x20},
	{ 0x07,0x00},
	{ 0x08,0x00},	
	//> 91
	//> 20
	//> 00
	//> 00
	//#			 mode is i2s,wordlength is 32 bit format
	{ 0x1b,0x30},
	//#			 NDAC is powered up and set to 4
	{ 0x0b,0x84},
	{ 0x0c,0x84},	
	//#			 MDAC is powered up and set to 4
	//> 84
	{ 0x12,0x84},
	{ 0x13,0x84},
	{ 0x14,0x00},
	{ 0x15,0x80},
	//> 84
	//#			 DOSR = 128, DOSR(9:8) = 0
	//> 00
	//#			             DOSR(7:0) = 128
	//> 80
	//#			 DAC =//> volume control thru pin disable 
	{ 0x74,0x00},
	//#			 DAC =//> drc disable, th and hy
	{ 0x44,0x00},
	//#			 DAC =//> 0 db gain left
	{ 0x41,0x00},
	{ 0x42,0x00},	
	//#			 DAC =//> 0 db gain right
	//> 00
	//#			--------------------------------------------------------------- page 3 (touch screen) is selected
	{ 0x00,0x01},
	//#			 De-pop, Power on = 800 ms, Step time = 4 ms
	{ 0x21,0x4e},
	//#			 HPL and HPR powered up
	{ 0x1f,0xc2},
	//#			 LDAC routed to HPL, RDAC routed to HPR
	{ 0x23,0x88},
	//#			 HPL unmute and gain 1db
	{ 0x28,0x0e},
	{ 0x29,0x0e},	
	//#			 HPR unmute and gain 1db
	//> 0e
	//#			 No attenuation on HP
	{ 0x24,0x00},
	{ 0x25,0x00},

	//#			 MIC BIAS = AVDD
	{ 0x2e,0x0b},
	//#			 MICPGA P = MIC 10k
	{ 0x30,0x40},
	{ 0x31,0x40},	
	//#			 MICPGA M - CM 10k
	//> 40
	//#			--------------------------------------------------------------- page 0 is selected
	{ 0x00,0x00},
	//#			 select DAC DSP mode 11 & enable adaptive filter
	{ 0x3c,0x0b},
	{ 0x00,0x08},
	{ 0x01,0x04},
	{ 0x00,0x00},
	//#			 POWERUP DAC left and right channels (soft step disable)
	{ 0x3f,0xd6},
	{ 0x40,0x00},	
	//#			 UNMUTE DAC left and right channels
	//> 00
	{ 0x00,0x01},
	{ 0x23,0x08},
	{ 0x23,0x00},
	{ 0x26,0x00},
	{ 0x27,0x00},
	{ 0x23,0x40},
	{ 0x23,0x44},
	{ 0x26,0xb0},
	{ 0x27,0xb0},
	{ 0x2a,0x0d},
	{ 0x2b,0x0d},
	{ 0x00,0x01},
	//#			 Unmute Class-D Left
	{ 0x2a,0x1c},
	//#			 Unmute Class-D Right
	{ 0x2b,0x1c},
	//#			 Power-up Class-D drivers
	{ 0x20,0xc6},
	{ 0x24,0x30},
	{ 0x25,0x30},
	{ 0x31,0x00},
	
	{0xFF,0xFF}
};
//============================================================================


void SetDAC3101AudioOn(unsigned char bAudioOnFlag)
{
	unsigned char  i ;

	if(bAudioOnFlag)
	{
		DAC3201_WriteI2C_Byte(0x41,acDAC3101_Volume[ucDACVolume]);
		DAC3201_WriteI2C_Byte(0x42,acDAC3101_Volume[ucDACVolume]);			
	}
	else
	{
		for(i = 0 ; acDAC3101_Audio_MuteOn[i].ucAddr != 0xFF ; i++)
		{
		DAC3201_WriteI2C_Byte(acDAC3101_Audio_MuteOn[i].ucAddr, acDAC3101_Audio_MuteOn[i].ucValue);
		}			
	}

}


void SetDAC3101Volume(unsigned char bInc)
{
	if(bInc==0)
	{
		if(ucDACVolume!=0)
			ucDACVolume--;
		else
			ucDACVolume=INDEX_MAX_VOL;
	}
	else
	{
		if(ucDACVolume<INDEX_MAX_VOL)
			ucDACVolume++;
		else
			ucDACVolume=0;
	}

	//Printf("Vol = %X \r\n",ucDACVolume);

	DAC3201_WriteI2C_Byte(0x41,acDAC3101_Volume[ucDACVolume]);
	DAC3201_WriteI2C_Byte(0x42,acDAC3101_Volume[ucDACVolume]);	
	
}



void SetDAC3101DefaultRegisterValue(void)
{
    unsigned char  i ;


    for(i = 0 ; acDAC3101_USB_Init[i].ucAddr != 0xFF ; i++)
    {
        DAC3201_WriteI2C_Byte(acDAC3101_USB_Init[i].ucAddr, acDAC3101_USB_Init[i].ucValue);
    }	

}

//////////////////////////////////////////////

uint08 check_I2C_Read_Req_polarity()
{
    uint08 pin_state = ACTIVE_LOW;
	pin_state = (P1IN & I2C_REQ_READ);

    if (pin_state == ACTIVE_LOW)
    {
        pin_state = 0;
    }
    else
    if (pin_state == ACTIVE_HIGH)
    {
        pin_state = 1;
    }

    return pin_state;
}

/***********************
#if 0
////////////////////////////////////////////////////
// Read CAIC switch polarity

uint08 check_CAIC_polarity()
{
    uint08 pin_state = ACTIVE_LOW;
	pin_state = (P1IN & CAIC_IN);
	
    if (pin_state == ACTIVE_LOW)
    {
        pin_state = 0;        
    }
    else
    if (pin_state == ACTIVE_HIGH)
    {
        pin_state = 1;      
    }

    return pin_state;
}

////////////////////////////////////////////////////
// Read LABB switch polarity

uint08 check_LABB_polarity()
{
    uint08 pin_state = ACTIVE_LOW;
	pin_state = (P1IN & LABB_IN);
	
    if (pin_state == ACTIVE_LOW)
    {
        pin_state = 0;        
    }
    else
    if (pin_state == ACTIVE_HIGH)
    {
        pin_state = 1;      
    }

    return pin_state;
}

////////////////////////////////////////////////////

void CAIC_LABB_Polling(void)
{
	uint08 newCAIC_st;
	uint08 newLABB_st;

	newCAIC_st = check_CAIC_polarity ();
	//If CAIC state is low, turn off the CAIC function.
	//If pin state is high, turn on the CAIC function.
	uint08 Param[2];


	if(CAIC_st != newCAIC_st )	
	{
		CAIC_st = newCAIC_st;
		
		if(CAIC_st == 0)
		{
		Param[0] = 0;  // RGB LED Current (disable CAIC algo)
		write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_LED_OUTPUT_CONTROL, Param, 1);
		Printf("disable CAIC algo ...\r\n");				
		}
		else
		{
		Param[0] = 1;  // RGB LED Current (enable CAIC algo)
		write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_LED_OUTPUT_CONTROL, Param, 1);
		Printf("enable CAIC algo ...\r\n");			
		}
	}

	newLABB_st = check_LABB_polarity ();

	if(LABB_st != newLABB_st )	
	{
		LABB_st = newLABB_st;

		//If LABB state is low, turn off the LABB function.
		//If pin state is high, turn on the LABB function.
		if(LABB_st == 0)
		{
			Param[0] = 0x60;  // Disable LABB algo. Sharpness is 6
			Param[1] = 0x3C;  // LABB strength is 60
			write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_LABB_CONTROL, Param, 2);
			Printf("Disable LABB algo ...\r\n");		
		}
		else
		{
			Param[0] = 0x61;  // Enable LABB algo in manual strength. Sharpness is 6
			Param[1] = 0x3C;  // LABB strength is 60
			write_dpp3430_i2c (DPP3430_DEV_ADDR, WRITE_LABB_CONTROL, Param, 2);
			Printf("Enable LABB algo ...\r\n");	

		}		
	}
}
#endif
*************************************/

////////////////////////////////////////////////////////////////////
// Keystone pitch angel adjustment.
void SetKeystone_Angle(uint08 Angle)
{
	uint08 Param[2];
	
	if(Angle==0)  // Decreasing keystone pitch angle until the minus angle max.
	{
		if(pitch_angle!=minus_angle_max)
			pitch_angle--;
		else
			pitch_angle=minus_angle_max;
	}
	else  // Increasing keystone pitch angle until the plus angle max.
	{
		if(pitch_angle<plus_angle_max)
			pitch_angle++;
		else
			pitch_angle=plus_angle_max;
	}

	//Printf("Keystone Angle = %X \r\n",pitch_angle);

	Param[0] = (uint08) (keystone_angle_array[pitch_angle]); // angle LSB
    Param[1] = (uint08) (keystone_angle_array[pitch_angle] >> 8); // angle MSB

	write_dpp3430_i2c (DPP3430_DEV_ADDR, Write_Keystone_Pitch_Angle, Param, 2);
	// Delay 20 ms
    Hold(20000);
	
	// If display mode at splash, then need to execute Splash screen everytime after Keystone adjustment.
	if(display_mode == disp_mode_splash)	
	// Write Splash screen execute
	{
	write_dpp3430_i2c(DPP3430_DEV_ADDR, WRITE_SPLASH_SCREEN_EXECUTE, NULL, 0);
	}
}

////////////////////////////////////////////////////////////////////
// Set Throw Ratio and DMD offset values for Keystone correction.
void SetKeystone_TR_OFS(void)
{
	uint08 Param[5];
	
	Param[0] = 0x01;  // Keystone Correction Enable; 0:Disable , 1:Enable
	Param[1] = 0xB3;  // Optical Throw Ratio LSB (Throw Ratio:1.7)
    Param[2] = 0x01;  // Optical Throw Ratio MSB (Throw Ratio:1.7)
    Param[3] = 0x00;  // Optical DMD Offset LSB  (DMD Offset:0%)
    Param[4] = 0x00;  // Optical DMD Offset MSB	 (0x00 is for DMD Offset 0%; value 0x01 for 100%)

	write_dpp3430_i2c (DPP3430_DEV_ADDR, Write_Keystone_Correction_Control, Param, 5);
	// Delay 20 ms
    Hold(20000);
}

/////////////////////////////////////////////////////
//Set DMD size
void SetDMD_size(void)
  // Read DMD ID to determine which DMD we have and decide it's DMD dimension

{
  	uint08 buf[4];
  	
	read_dpp3430_i2c (DPP3430_DEV_ADDR, READ_DMD_ID, NULL, 1, buf, 4);
	// DMD ID: 06 b0 00 26 or 0x60 0x0d 0x00 0x64 for .2 wVGA
	// DMD ID: 06 b0 00 16 or 0x60 0x0d 0x00 0x68 for .3 720p
	if (buf[3] == 0x26 || buf[3] == 0x64 || buf[3] == 0x69)
	{
		// .2 wVGA size
		DMDx = 854;
		DMDy = 480;
	}
	else if (buf[3] == 0x16 || buf[3] == 0x68)		
	{
		// 720p DMD
		DMDx = 1280;
		DMDy = 720;
	} 
	else
	if (buf[3] == 0x6B)
	{
		// 1080p DMD
		DMDx = 1920;
		DMDy = 1080;			
	}
	else
	{
		DMDx = 854;
		DMDy = 480;		
	}
}	
